<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Field;
use App\Models\FieldSubject;
use App\Models\Subject;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class FieldsController extends Controller
{
    public function index()
    {
        $fields = Field::orderBy('name')->paginate(20);

        return view('admin.fields.index', compact('fields'));
    }

    public function search(Request $request)
    {
        if ($request->ajax()) {
            $search = $request->get('query');
            $search = str_replace(" ", "%", $search);

            $fields = Field::where('name', 'LIKE', '%' . $search . '%')
                ->orWhere('shortname', 'LIKE', '%' . $search . '%')
                ->orderBy('name')->paginate(20);

            return view('admin.fields.list', compact('fields'))->render();
        }
    }

    public function create()
    {
        return view('admin.fields.create');

    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|unique:fields',
            'shortname' => 'required|string|unique:fields',
            'years' => 'required|int|min:0',
            'credits' => 'required|int|min:0',
        ]);

        $field = Field::create([
            'name' => $request->input('name'),
            'shortname' => $request->input('shortname'),
            'years' => $request->input('years'),
            'credits' => $request->input('credits'),
        ]);

        return redirect('/admin/fields');

    }

    public function edit(int $id_field)
    {
        $field = Field::find($id_field);

        return view('admin/fields/edit')->with('field', $field);

    }

    public function update(Request $request, int $id_field)
    {
        $request->validate([
            'name' => 'required|string|unique:fields,name,' . $id_field,
            'shortname' => 'required|string|unique:fields,shortname,' . $id_field,
            'years' => 'required|int|min:0',
            'credits' => 'required|int|min:0',
        ]);

        $field = Field::where('id', $id_field)
            ->update([
                'name' => $request->input('name'),
                'shortname' => $request->input('shortname'),
                'years' => $request->input('years'),
                'credits' => $request->input('credits'),
            ]);

        return redirect('/admin/fields');

    }

    public function destroy(int $id_field)
    {
        $field = Field::find($id_field);
        $field->delete();

        return redirect('/admin/fields');

    }

    public function show(int $id_field)
    {
        $field = Field::find($id_field);

        return view('admin.fields.show')->with('field', $field);

    }

    public function subjects(int $id_field)
    {
        $field = Field::find($id_field);
        $subjects = Subject::whereNotExists(function ($query) use ($field) {
            $query->select(DB::raw(1))
                ->from('fields_subjects')
                ->whereRaw('subjects.id = fields_subjects.subject_id')
                ->where('fields_subjects.field_id', $field->id);
        })->orderBy('name')->get();

        return view('admin.fields.subjects', [
            'field' => $field,
            'subjects' => $subjects,
        ]);

    }

    public function addSubject(Request $request, int $id_field)
    {
        $subjects = $request->input('subjects');

        if ($subjects != null) {
            foreach ($subjects as $subject) {

                $fieldSubject = FieldSubject::create([
                    'field_id' => $id_field,
                    'subject_id' => $subject,
                ]);
            }
        }

        return redirect('/admin/fields/' . $id_field);

    }

    public function deleteSubject(Request $request, int $id_field)
    {
        $subjects = $request->input('subjects');

        if ($subjects != null) {
            foreach ($subjects as $subject) {

                $subject = FieldSubject::where('field_id', $id_field)->where('subject_id', $subject)->first();
                $subject->delete();
            }
        }

        return redirect('/admin/fields/' . $id_field);
    }
}
