<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Schedule;
use App\Models\Setting;
use Illuminate\Http\Request;

class SchedulesController extends Controller
{
    public function index(int $year)
    {
        $setting = Setting::first();
        $schedules_first = Schedule::where('year', $year)->where('date_start', '>=', $setting->first_semester_start)->where('date_start', '<=', $setting->first_semester_end)->orderBy('date_start')->get();
        $schedules_second = Schedule::where('year', $year)->where('date_start', '>=', $setting->second_semester_start)->where('date_start', '<', $setting->second_semester_end)->orderBy('date_start')->get();

        return view('years.schedules.index', [
            'schedules_first' => $schedules_first,
            'schedules_second' => $schedules_second,
            'setting' => $setting,
            'year' => $year,
        ]);
    }

    public function create(int $year)
    {
        return view('admin.schedules.create', [
            'year' => $year,
        ]);

    }

    public function store(Request $request, int $year)
    {
        $request->validate([
            'date_start' => 'required|date',
            'date_end' => 'sometimes|nullable|date|after_or_equal:date_start',
            'text' => 'required|string',
        ]);

        $schedule = Schedule::create([
            'date_start' => $request->input('date_start'),
            'date_end' => $request->input('date_end'),
            'text' => $request->input('text'),
            'year' => $year,
        ]);

        return redirect('/admin/years/' . $year . '/schedules/');
    }

    public function edit(int $year, int $schedule_id)
    {
        $schedule = Schedule::find($schedule_id);

        return view('admin.schedules.edit', [
            'schedule' => $schedule,
            'year' => $year,
        ]);
    }

    public function update(Request $request, int $year, int $schedule_id)
    {
        $request->validate([
            'date_start' => 'required|date',
            'date_end' => 'sometimes|nullable|date|after_or_equal:date_start',
            'text' => 'required|string',
        ]);

        $schedule = Schedule::where('id', $schedule_id)->update([
            'date_start' => $request->input('date_start'),
            'date_end' => $request->input('date_end'),
            'text' => $request->input('text'),
        ]);

        return redirect('/admin/years/' . $year . '/schedules/');
    }

    public function destroy(Request $request, int $year, int $schedule_id)
    {
        $schedule = Schedule::find($schedule_id);
        $schedule->delete();

        return redirect()->back();
    }
}
