<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Field;
use App\Models\Setting;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class StudentsController extends Controller
{
    public function index()
    {
        $users = User::where('authorization', 3)->orderBy('lastname')->paginate(20);

        return view('admin.students.index', compact('users'));
    }

    public function search(Request $request)
    {
        if ($request->ajax()) {
            $search = $request->get('query');
            $search = str_replace(" ", "%", $search);

            $users = User::where(DB::raw('concat(firstname," ",lastname)'), 'like', '%'.$search.'%')->where('authorization', 3)
                ->orWhere('lastname', 'LIKE', '%' . $search . '%')->where('authorization', 3)
                ->orWhere('firstname', 'LIKE', '%' . $search . '%')->where('authorization', 3)
                ->orWhere('username', 'LIKE', '%' . $search . '%')->where('authorization', 3)
                ->orWhere('email', 'LIKE', '%' . $search . '%')->where('authorization', 3)
                ->orderBy('lastname')->paginate(20);

            return view('admin.students.list', compact('users'))->render();
        }
    }

    public function show(int $user_id)
    {
        $user = User::find($user_id);

        return view('admin.students.show', [
            'user' => $user,
        ]);
    }

    public function create()
    {
        $fields = Field::orderBy('name')->get();

        return view('admin.students.create')->with('fields', $fields);
    }

    public function store(Request $request)
    {
        $request->validate([
            'firstname' => 'required|string',
            'lastname' => 'required|string',
            'id_field' => 'required|integer',
        ]);

        $firstname = $request->input('firstname');
        $lastname = $request->input('lastname');

        $data = $this->username($firstname, $lastname);

        $user = User::create([
            'firstname' => $firstname,
            'lastname' => $lastname,
            'username' => $data['username'],
            'email' => $data['email'],
            'password' => Hash::make($data['username']),
            'study_year' => Carbon::now()->format('Y-m-d\TH:i'),
            'authorization' => 3,
            'field_id' => $request->input('id_field'),
        ]);

        return redirect('/admin/students');
    }

    public function edit(int $id)
    {
        $user = User::find($id);
        $fields = Field::orderBy('name')->get();

        return view('admin.students.edit', [
            'user' => $user,
            'fields' => $fields,
        ]);
    }

    public function update(Request $request, int $id)
    {
        $request->validate([
            'firstname' => 'required|string',
            'lastname' => 'required|string',
            'field_id' => 'required|integer',
        ]);

        $firstname = $request->input('firstname');
        $lastname = $request->input('lastname');

        $data = $this->username($firstname, $lastname);

        $user = User::where('id', $id)
            ->update([
                'firstname' => $firstname,
                'lastname' => $lastname,
                'username' => $data['username'],
                'email' => $data['email'],
                'field_id' => $request->input('field_id'),
            ]);

        return redirect('/admin/students');
    }

    public function destroy(int $id)
    {
        $user = User::find($id);

        $user->delete();

        return redirect('/admin/students');
    }

    private function username(string $firstname, string $lastname)
    {
        $setting = Setting::first();

        $count = User::where('firstname', $firstname)
            ->where('lastname', $lastname)
            ->count();

        $username = strtolower(substr(Str::ascii($lastname), 0, $setting->lastname)) . strtolower(substr(Str::ascii($firstname), 0, $setting->firstname)) . ($count + 1);

        $email = $username . "@" . $setting->email;

        return [
            'username' => $username,
            'email' => $email,
        ];
    }
}
