<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Subject;
use App\Models\User;
use App\Models\UserSubject;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class SubjectsController extends Controller
{
    public function index()
    {
        $subjects = Subject::orderBy('name')->paginate(20);

        return view('admin.subjects.index', compact('subjects'));
    }

    public function search(Request $request)
    {
        if ($request->ajax()) {
            $search = $request->get('query');
            $search = str_replace(" ", "%", $search);

            $subjects = Subject::where('name', 'LIKE', '%' . $search . '%')
                ->orWhere('shortname', 'LIKE', '%' . $search . '%')
                ->orderBy('name')->paginate(20);

            return view('admin.subjects.list', compact('subjects'))->render();
        }
    }

    public function create()
    {
        return view('admin.subjects.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|unique:subjects',
            'shortname' => 'required|string|unique:subjects',
            'study_year' => 'required|integer|min:1|max:3',
            'semester' => 'required|integer|min:1|max:2',
            'examination' => 'required|integer|min:1|max:2',
            'credits' => 'required|integer|min:1|max:10',
            'sylabus' => 'required|string',
        ]);

        $subject = Subject::create([
            'name' => $request->input('name'),
            'shortname' => $request->input('shortname'),
            'study_year' => $request->input('study_year'),
            'semester' => $request->input('semester'),
            'examination' => $request->input('examination'),
            'credits' => $request->input('credits'),
            'sylabus' => $request->input('sylabus'),
        ]);

        $category = Category::create([
            'name' => 'Výchozí kategorie',
            'parent_category_id' => NULL,
            'subject_id' => $subject->id,
        ]);

        return redirect('/admin/subjects');
    }

    public function edit(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('admin.subjects.edit')->with('subject', $subject);
    }

    public function update(Request $request, int $id_subject)
    {
        $request->validate([
            'name' => 'required|string|unique:subjects,name,' . $id_subject,
            'shortname' => 'required|string|unique:subjects,shortname,' . $id_subject,
            'study_year' => 'required|integer|min:1|max:3',
            'semester' => 'required|integer|min:1|max:2',
            'examination' => 'required|integer|min:1|max:2',
            'credits' => 'required|integer|min:1|max:10',
            'sylabus' => 'required|string',
        ]);

        $subject = Subject::where('id', $id_subject)
            ->update([
                'name' => $request->input('name'),
                'shortname' => $request->input('shortname'),
                'study_year' => $request->input('study_year'),
                'semester' => $request->input('semester'),
                'examination' => $request->input('examination'),
                'credits' => $request->input('credits'),
                'sylabus' => $request->input('sylabus'),
            ]);

        return redirect('/admin/subjects');
    }

    public function destroy($id_subject)
    {
        $subject = Subject::find($id_subject);
        $subject->delete();

        return redirect('/admin/subjects');
    }

    public function show(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('admin.subjects.show')->with('subject', $subject);
    }

    public function teachers(int $id_subject)
    {
        $subject = Subject::find($id_subject);
        $teachers = User::where('authorization', 2)->whereNotExists(function ($query) use ($subject) {
            $query->select(DB::raw(1))
                ->from('users_subjects')
                ->whereRaw('users.id = users_subjects.user_id')
                ->where('users_subjects.subject_id', $subject->id);
        })->orderBy('lastname')->get();

        return view('admin.subjects.teachers', [
            'subject' => $subject,
            'teachers' => $teachers,
        ]);
    }

    public function addTeacher(Request $request, int $id_subject)
    {
        $teachers = $request->input('users');

        if ($teachers != null) {
            foreach ($teachers as $teacher) {

                $userSubject = UserSubject::create([
                    'subject_id' => $id_subject,
                    'user_id' => $teacher,
                ]);
            }
        }

        return redirect('/admin/subjects/' . $id_subject);
    }

    public function deleteTeacher(Request $request, int $id_subject)
    {
        $teachers = $request->input('users');

        if ($teachers != null) {
            foreach ($teachers as $teacher) {
                $user = UserSubject::where('subject_id', $id_subject)->where('user_id', $teacher)->first();
                $user->delete();
            }
        }

        return redirect('/admin/subjects/' . $id_subject);
    }
}
