<?php

namespace App\Http\Controllers\Student;

use App\Http\Controllers\Controller;
use App\Models\Lesson;
use App\Models\Preregistration;
use App\Models\Setting;
use App\Models\User;
use App\Models\UserLesson;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use function PHPUnit\Framework\isEmpty;

class LessonsController extends Controller
{
    public function index()
    {
        $user = User::where('id', Auth::user()->id)->first();
        $setting = Setting::first();
        $subjects = $user->subjects;
        $lessons = '';

        $colors = ['amber', 'lime', 'cyan', 'violet', 'rose', 'lemon', 'navy', 'viridian'];

        if ($subjects->count() > 0) {
            $preregistrationLessons = $user->preregistration;

            $lessons = collect(new Lesson());
            foreach ($subjects as $key => $subject) {
                $color = $colors[$key];
                unset($colors[$key]);
                foreach ($subject->lessons as $lesson) {
                    $lesson->setAttribute('color', $color);
                }
                $lessons = $lessons->merge($subject->lessons);
            }

            foreach ($preregistrationLessons as $preLesson) {
                $lesson = $lessons->where("id", $preLesson->id)->first;
                $lesson->setAttribute('preregistration', true);
            }
        }

        $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');

        return view('lessons.index', [
            'lessons' => $lessons,
            'setting' => $setting,
            'now' => $now,
        ]);
    }

    public function preregistration(Request $request)
    {
        $user = Auth::user()->id;
        $lesson_id = $request->input('id');
        $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');
        $setting = Setting::first();

        if (($now >= $setting->preregistration && $now <= $setting->end_registration) && !Preregistration::where('user_id', $user)->where('lesson_id', $lesson_id)->exists()) {

            Preregistration::create([
                'user_id' => $user,
                'lesson_id' => $lesson_id
            ]);
        }

        return true;
    }

    public function preunregistration(Request $request)
    {
        $user = Auth::user()->id;
        $lesson_id = $request->input('id');
        $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');
        $setting = Setting::first();

        if (($now >= $setting->preregistration && $now <= $setting->end_registration) && Preregistration::where('user_id', $user)->where('lesson_id', $lesson_id)->exists()) {

            $preregistration = Preregistration::where('user_id', $user)->where('lesson_id', $lesson_id)->first();
            $preregistration->delete();
        }

        return true;
    }

    public function registration(Request $request)
    {
        $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');
        $setting = Setting::first();

        if ($now >= $setting->registration && $now <= $setting->end_registration) {

            $user = User::find(Auth::user()->id);
            $input = $request->input('lessons');
            $userLessons = $user->lessons;

            if ($input !== null) {
                $lessons = Lesson::whereIn('id', $input)->get();
                foreach ($lessons as $lesson) {

                    if ($lesson->occupancy < $lesson->capacity && !UserLesson::where('user_id', $user->id)->where('lesson_id', $lesson->id)->exists()) {

                        $lesson->update([
                            'occupancy' => ($lesson->occupancy + 1),
                        ]);

                        UserLesson::create([
                            'user_id' => $user->id,
                            'lesson_id' => $lesson->id,
                        ]);
                    }
                }

                $userLessons = $user->lessons;
                $unregister = $userLessons->diff($lessons);
            } else {
                $unregister = $userLessons;
            }

            foreach ($unregister as $lesson) {
                if (UserLesson::where('user_id', $user->id)->where('lesson_id', $lesson->id)->exists()) {
                    $lesson = Lesson::where('id', $lesson->id)->first();

                    $lesson->update([
                        'occupancy' => ($lesson->occupancy - 1),
                    ]);

                    $registration = UserLesson::where('user_id', $user->id)->where('lesson_id', $lesson->id)->first();
                    $registration->delete();
                }
            }
        }
        return redirect()->back();
    }
}
