<?php

namespace App\Http\Controllers\Student;

use App\Http\Controllers\Controller;
use App\Models\Field;
use App\Models\Setting;
use App\Models\Subject;
use App\Models\User;
use App\Models\UserSubject;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class SubjectsController extends Controller
{
    public function index(Request $request)
    {
        if ($request->has('study_year')){
            $study_year = $request->get('study_year');
            $semester = $request->get('semester');
        } else {
            $study_year = 1;
            $semester = 1;
        }

        $setting = Setting::first();
        $user = User::where('id', Auth::user()->id)->first();
        $field = Field::find($user->field_id);

        $field_subjects = $field->subjects->where('study_year', $study_year)->where('semester', $semester);
        $user_subjects = $user->subjects->where('study_year', $study_year)->where('semester', $semester);

        $preregistrationLessons = $user->preregistration;
        $registrationLessons = $user->lessons;

        foreach ($user_subjects as $subject) {
            $field_subject = $field_subjects->find($subject->id);

            if ($subject->pivot->completed === 1) {
                $field_subject->setAttribute('completed', 1);
            } elseif ($subject->pivot->completed === 2) {
                $field_subject->setAttribute('completed', 2);
                $field_subject->setAttribute('attempts', $subject->pivot->attempts);
            } elseif ($subject->pivot->completed === 0) {
                $field_subject->setAttribute('completed', 0);

                $lecturesCount = $subject->lectures->count();
                $practiceCount = $subject->practice->count();

                $preLessons = $preregistrationLessons->where('subject_id', $subject->id);
                $prePractice = $preLessons->where('type', 2)->count();
                $preLectures = $preLessons->where('type', 1)->count();

                $lessons = $registrationLessons->where('subject_id', $subject->id);
                $practice = $lessons->where('type', 2)->count();
                $lectures = $lessons->where('type', 1)->count();

                if (($practiceCount > 0 && $practice > 0) || ($practiceCount === 0 && $practice === 0 && $lecturesCount > 0)) {
                    if (($lecturesCount > 0 && $lectures > 0) || ($lecturesCount === 0 && $lectures === 0)) {
                        $field_subject->setAttribute('registration', true);
                    }
                } elseif (($practiceCount > 0 && $prePractice > 0) || ($practiceCount === 0 && $prePractice === 0 && $lecturesCount > 0)) {
                    if (($lecturesCount > 0 && $preLectures > 0) || ($lecturesCount === 0 && $preLectures === 0)) {
                        $field_subject->setAttribute('preregistration', true);
                    }
                } elseif ($subject->pivot->enroll === 1) {
                    $field_subject->setAttribute('enroll', true);
                } elseif ($subject->pivot->enroll === 0) {
                    $field_subject->setAttribute('enroll', false);
                }
            }
        }

        $now = Carbon::now();
        if ($now > $setting->first_semester_start && $now < $setting->first_semester_end) {
            $semesterNow = 1;
        } else {
            $semesterNow = 2;
        }

        return view('subjects.index', [
            'setting' => $setting,
            'subjects' => $field_subjects,
            'now' => $now,
            'semester' => $semester,
            'semesterNow' => $semesterNow,
            'study_year' => $study_year,
        ]);
    }

    public function filter(Request $request)
    {
        if ($request->ajax()) {
            $study_year = $request->get('select');
            $semester = $request->get('select2');
            $setting = Setting::first();

            $user = User::where('id', Auth::user()->id)->first();
            $field = Field::find($user->field_id);

            $field_subjects = $field->subjects->where('study_year', $study_year)->where('semester', $semester);
            $user_subjects = $user->subjects->where('study_year', $study_year)->where('semester', $semester);


            $preregistrationLessons = $user->preregistration;
            $registrationLessons = $user->lessons;

            foreach ($user_subjects as $subject) {
                $field_subject = $field_subjects->find($subject->id);

                if ($subject->pivot->completed === 1) {
                    $field_subject->setAttribute('completed', 1);
                } elseif ($subject->pivot->completed === 2) {
                    $field_subject->setAttribute('completed', 2);
                    $field_subject->setAttribute('attempts', $subject->pivot->attempts);
                } elseif ($subject->pivot->completed === 0) {
                    $field_subject->setAttribute('completed', 0);

                    $lecturesCount = $subject->lectures->count();
                    $practiceCount = $subject->practice->count();

                    $preLessons = $preregistrationLessons->where('subject_id', $subject->id);
                    $prePractice = $preLessons->where('type', 2)->count();
                    $preLectures = $preLessons->where('type', 1)->count();

                    $lessons = $registrationLessons->where('subject_id', $subject->id);
                    $practice = $lessons->where('type', 2)->count();
                    $lectures = $lessons->where('type', 1)->count();

                    if (($practiceCount > 0 && $practice > 0) || ($practiceCount === 0 && $practice === 0 && $lecturesCount > 0)) {
                        if (($lecturesCount > 0 && $lectures > 0) || ($lecturesCount === 0 && $lectures === 0)) {
                            $field_subject->setAttribute('registration', true);
                        }
                    } elseif (($practiceCount > 0 && $prePractice > 0) || ($practiceCount === 0 && $prePractice === 0 && $lecturesCount > 0)) {
                        if (($lecturesCount > 0 && $preLectures > 0) || ($lecturesCount === 0 && $preLectures === 0)) {
                            $field_subject->setAttribute('preregistration', true);
                        }
                    } elseif ($subject->pivot->enroll === 1) {
                        $field_subject->setAttribute('enroll', true);
                    } elseif ($subject->pivot->enroll === 0) {
                        $field_subject->setAttribute('enroll', false);
                    }
                }
            }

            $now = Carbon::now();
            if ($now > $setting->first_semester_start && $now < $setting->first_semester_end) {
                $semesterNow = 1;
            } else {
                $semesterNow = 2;
            }


            return view('subjects.list', [
                'setting' => $setting,
                'subjects' => $field_subjects,
                'now' => $now,
                'semester' => $semester,
                'semesterNow' => $semesterNow,
                'study_year' => $study_year,
            ])->render();
        }
    }

    public function enroll(int $subject_id)
    {
        $setting = Setting::first();
        $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');

        if ($now >= $setting->preregistration && $now <= $setting->end_registration) {
            $user_subject = UserSubject::where('user_id', Auth::user()->id)->where('subject_id', $subject_id)->first();

            if ($user_subject !== null) {
                $user_subject->update([
                    'enroll' => 1,
                    'completed' => 0,
                ]);
            } else {
                $user_subject = UserSubject::create([
                    'user_id' => Auth::user()->id,
                    'subject_id' => $subject_id,
                    'attempts' => $setting->attempts,
                    'enroll' => 1,
                ]);
            }
        }

        $study_year = $_GET['study_year'];
        $semester = $_GET['semester'];

        return redirect('/subjects?study_year=' . $study_year . '&semester=' . $semester);
    }

    public function unroll(int $subject_id)
    {
        $setting = Setting::first();
        $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');

        if ($now >= $setting->preregistration && $now <= $setting->end_registration) {
            $user_subject = UserSubject::where('user_id', Auth::user()->id)->where('subject_id', $subject_id)->first();

            if ($user_subject->attempts < $setting->attempts) {
                $user_subject->update([
                    'enroll' => 0,
                    'completed' => 0,
                ]);
            } else {
                $user_subject->delete();
            }
        }

        $study_year = $_GET['study_year'];
        $semester = $_GET['semester'];

        return redirect('/subjects?study_year=' . $study_year . '&semester=' . $semester);
    }

    public function sylabus($id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.sylabus')->with('subject', $subject);
    }

    public function contacts($id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.contacts')->with('subject', $subject);
    }
}
