<?php

namespace App\Http\Controllers\Student;

use App\Http\Controllers\Controller;
use App\Models\Attempt;
use App\Models\Menu;
use App\Models\Notification;
use App\Models\Setting;
use App\Models\Subject;
use App\Models\Test;
use App\Models\UserAnswer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class TestsController extends Controller
{

    public function show(int $id_subject, int $id_menu, int $id_test)
    {
        $userAttempt = Attempt::where('user_id', Auth::user()->id)->where('test_id', $id_test)->first();
        $test = Test::find($id_test);

        if (($userAttempt === null && $test->password === null) || ($test->password !== null && session('test') === $id_test)) {
            \Illuminate\Support\Facades\Session::forget('test');

            $subject = Subject::find($id_subject);
            $menu = Menu::find($id_menu);
            $id_user = Auth::user()->id;

            if ($test->questions->isNotEmpty()) {
                $attempt = Attempt::create([
                    'name' => $test->name,
                    'user_id' => $id_user,
                    'test_id' => $id_test,
                    'subject_id' => $id_subject,
                    'points' => 0,
                    'max_points' => $test->points,
                ]);

                if (Auth::user()->authorization === 3 && !Notification::where('type', 1)->where('user_id', $id_user)->where('subject_id', $id_subject)->where('attempt_id', $attempt->id)->exists()) {
                    Notification::create([
                        'type' => 1,
                        'user_id' => $id_user,
                        'subject_id' => $id_subject,
                        'attempt_id' => $attempt->id,
                    ]);
                }

                foreach ($test->questions as $question) {
                    UserAnswer::create([
                        'user_id' => Auth::user()->id,
                        'test_question_id' => $question->pivot->id,
                        'test_id' => $id_test,
                        'attempt_id' => $attempt->id,
                        'value' => null,
                        'point' => 0,
                    ]);
                }
            }

            $setting = Setting::first();

            return view('subjects.menus.tests.show', [
                'setting' => $setting,
                'subject' => $subject,
                'menu' => $menu,
                'test' => $test,
            ]);
        }

        if ($userAttempt !== null) {
            return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu . '/tests/' . $id_test . '/attempts/' . $userAttempt->id);
        }

        if ($test->password !== null) {
            return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu . '/tests/' . $test->id . '/enroll');
        }
    }

    public function check(Request $request, int $id_subject, int $id_menu, int $id_test)
    {
        $test = Test::find($id_test);


        $answers = $request->input('answer');
        $points = 0;

        if ($answers != null) {
            foreach ($test->questions as $question) {
                $point = 0;

                if (array_key_exists($question->id, $answers) && $answers[$question->id] !== null) {
                    $answer = $answers[$question->id];
                    $countOfAnswers = count($question->answersRight);
                    if ($question->type === 1) {

                        if ($countOfAnswers === 1) {
                            if ($question->answersRight[0]->id == $answer) {
                                $point = $question->pivot->point;
                            }
                        } elseif ($countOfAnswers > 1) {
                            $count = 0;
                            foreach ($answer as $ans) {
                                $i = 0;
                                foreach ($question->answersRight as $rightAnswer) {
                                    if ($ans == $rightAnswer->id) {
                                        $i++;
                                    }
                                }
                                if ($i === 1) {
                                    $count++;
                                } else {
                                    $count--;
                                }
                            }

                            if ($count === $countOfAnswers) {
                                $point = $question->pivot->point;
                            } elseif ($count < $countOfAnswers && $count > 0) {
                                $percent = $count / ($countOfAnswers / 100);
                                $point = ($question->pivot->point / 100) * $percent;
                            } elseif ($count <= 0) {
                                $point = 0;
                            }
                        }

                    } elseif ($question->type === 2) {
                        if ($question->answers[0]->answer == $answer) {
                            $point = $question->pivot->point;
                        }

                    } elseif ($question->type === 3) {
                        foreach ($question->answersRight as $answerRight) {
                            if ($answerRight->answer === $answer) {
                                $point = $question->pivot->point;
                                continue;
                            }
                        }
                    }
                } else {
                    $answer = null;
                }

                UserAnswer::where('test_id', $id_test)->where('user_id', Auth::user()->id)->where('test_question_id', $question->pivot->id)->update([
                    'value' => $answer,
                    'point' => $point,
                ]);

                $points += $point;
            }
        }

        $userAttempt = Attempt::where('user_id', Auth::user()->id)->where('test_id', $id_test)->first();

        $userAttempt->update([
            'points' => $points,
        ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu . '/tests/' . $id_test . '/attempts/' . $userAttempt->id);
    }

    public function enroll(int $id_subject, int $id_menu, int $id_test)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);
        $test = Test::find($id_test);

        return view('subjects.menus.tests.enroll', [
            'subject' => $subject,
            'menu' => $menu,
            'test' => $test,
        ]);
    }

    public function verify(Request $request, int $id_subject, int $id_menu, int $id_test)
    {
        $request->validate([
            'password' => 'required|string',
        ]);

        $test = Test::find($id_test);

        if (Hash::check($request->input('password'), $test->password)) {
            session(['test' => $id_test]);

            return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu . '/tests/' . $id_test);
        }

        return redirect()->back();
    }
}
