<?php

namespace App\Http\Controllers\Student;

use App\Http\Controllers\Controller;
use App\Models\Classification;
use App\Models\Setting;
use App\Models\Subject;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules;

class UsersController extends Controller
{
    public function subjects()
    {
        $user = User::find(Auth::user()->id);

        if (Auth::user()->authorization === 1) {
            $user->subjects = Subject::orderBy('name')->get();
        }

        return view('users.subjects')->with('user', $user);
    }


    public function profile()
    {
        $user = User::find(Auth::user()->id);
        $subjects = $user->subjects->where('study_year', 1);
        $text = ['A', 'B', 'C', 'D', 'E', 'F'];

        foreach ($subjects as $subject) {
            $classification = Classification::where('subject_id', $subject->id)->where('user_id', $user->id)->first();
            if ($classification !== null) {
                if ($classification->exam !== null) {
                    $subject->setAttribute('exam', $text[$classification->exam - 1]);
                }
                if ($classification->credit !== null) {
                    $subject->setAttribute('credit', $text[$classification->credit - 1]);
                }
            }
        }

        if ($user->authorization === 3 || $user->authorization === 2) {
            $setting = Setting::first();
            $colors = ['amber', 'lime', 'cyan', 'violet', 'rose', 'lemon', 'navy', 'viridian'];
            $userLessons = "";

            if ($subjects) {
                if ($user->authorization === 3) {
                    $examDates = $user->examDates;
                    $userLessons = $user->lessons;

                } elseif ($user->authorization === 2) {
                    $examDates = $user->teacherExamDates;
                    $userLessons = $user->teacherLessons;
                }

                foreach ($subjects as $key => $subject) {
                    $color = $colors[$key];
                    unset($colors[$key]);
                    foreach ($userLessons->where('subject_id', $subject->id) as $lesson) {
                        $lesson->setAttribute('color', $color);
                    }
                }
            }

            $now = \Carbon\Carbon::now()->format('Y-m-d\TH:i');


            return view('users.profile', [
                'lessons' => $userLessons,
                'setting' => $setting,
                'examDates' => $examDates,
                'now' => $now,
                'user' => $user,
                'subjects' => $subjects,
            ]);
        }

        return view('users.profile', [
            'user' => $user,
            'subjects' => $subjects,
        ]);
    }

    public function filter(Request $request)
    {
        if ($request->ajax()) {
            $study_year = $request->get('select');
            $user = User::find(Auth::user()->id);
            $subjects = $user->subjects->where('study_year', $study_year);
            $text = ['A', 'B', 'C', 'D', 'E', 'F'];

            foreach ($subjects as $subject) {
                $classification = Classification::where('subject_id', $subject->id)->where('user_id', $user->id)->first();
                if ($classification !== null) {
                    if ($classification->exam !== null) {
                        $subject->setAttribute('exam', $text[$classification->exam]);
                    }
                    if ($classification->credit !== null) {
                        $subject->setAttribute('credit', $text[$classification->credit]);
                    }
                }
            }

            return view('users.list', [
                'subjects' => $subjects,
            ])->render();
        }
    }

    public function passwordEdit()
    {
        return view('users.change', [
        ]);
    }

    public function passwordUpdate(Request $request)
    {
        $match = Hash::check($request->input('current-password'), Auth::user()->password);

        if (!$match) {
            return redirect()->back()->withErrors(["current-password" => "Staré heslo se neschoduje."]);
        }

        $request->validate([
            'current-password' => ['required'],
            'password' => ['required', Rules\Password::min(8)->mixedCase()->numbers()],
            'new-confirm-password' => ['same:password', Rules\Password::min(8)->mixedCase()->numbers()],
        ]);

        User::find(auth()->user()->id)->update(['password'=> Hash::make($request->input('password'))]);

        return redirect('/users/profile');
    }
}
