<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Attempt;
use App\Models\Notification;
use App\Models\Subject;
use App\Models\User;
use App\Models\UserAnswer;
use App\Models\UserSubject;
use Carbon\Carbon;
use Illuminate\Http\Request;

class AttemptsController extends Controller
{
    public function create(int $subject_id, int $user_id)
    {
        $subject = Subject::find($subject_id);
        $user = User::find($user_id);

        return view('subjects.menus.tests.attempts.create', [
            'subject' => $subject,
            'user' => $user,
        ]);
    }

    public function store(Request $request, int $subject_id, int $user_id)
    {
        $request->validate([
            'name' => 'required|string',
            'points' => 'required|integer|min:0',
            'max_points' => 'required|integer|min:0',
            'text' => 'nullable|string',
        ]);

        $attempt = Attempt::create([
            'name' => $request->input('name'),
            'points' => $request->input('points'),
            'max_points' => $request->input('max_points'),
            'text' => $request->input('text'),
            'user_id' => $user_id,
            'subject_id' => $subject_id,
        ]);

        if (!Notification::where('type', 1)->where('user_id', $user_id)->where('subject_id', $subject_id)->where('attempt_id', $attempt->id)->exists()) {
            Notification::create([
                'type' => 1,
                'user_id' => $user_id,
                'subject_id' => $subject_id,
                'attempt_id' => $attempt->id,
            ]);
        }

        $userSubject = UserSubject::where('user_id', $user_id)->where('subject_id', $subject_id)->first();

        $userSubject->update([
            'updated_at' => Carbon::now(),
        ]);

        return redirect('/subjects/' . $subject_id . '/students');
    }

    public function edit(int $subject_id, int $user_id, int $attempt_id)
    {
        $subject = Subject::find($subject_id);
        $user = User::find($user_id);
        $attempt = Attempt::find($attempt_id);

        return view('subjects.menus.tests.attempts.edit', [
            'subject' => $subject,
            'user' => $user,
            'attempt' => $attempt,
        ]);
    }

    public function update(Request $request, int $subject_id, int $user_id, int $attempt_id)
    {
        $request->validate([
            'name' => 'nullable|string',
            'points' => 'nullable|integer|min:0',
            'max_points' => 'nullable|integer|min:0',
            'text' => 'nullable|string',
        ]);

        $attempt = Attempt::find($attempt_id);

        if ($request->input('name') === null && $request->input('points') === null && $request->input('max_points') === null) {
            $name = $attempt->name;
            $points = $attempt->points;
            $max_points = $attempt->max_points;
        } else {
            $name = $request->input('name');
            $points = $request->input('points');
            $max_points = $request->input('max_points');
        }

        $attempt->update([
            'name' => $name,
            'points' => $points,
            'max_points' => $max_points,
            'text' => $request->input('text'),
        ]);

        if (!Notification::where('type', 2)->where('user_id', $user_id)->where('subject_id', $subject_id)->where('attempt_id', $attempt_id)->exists()) {
            Notification::create([
                'type' => 2,
                'user_id' => $user_id,
                'subject_id' => $subject_id,
                'attempt_id' => $attempt_id,
            ]);
        }

        $userSubject = UserSubject::where('user_id', $user_id)->where('subject_id', $subject_id)->first();

        $userSubject->update([
            'updated_at' => Carbon::now(),
        ]);

        return redirect('/subjects/' . $subject_id . '/students');
    }

    public function destroy(int $subject_id, int $user_id, int $attempt_id)
    {
        $attempt = Attempt::find($attempt_id);
        $attempt->delete();

        return redirect()->back();
    }

    public function updatePoint(Request $request)
    {
        $user_id = $request->input('user_id');

        $userAnswer = UserAnswer::where('user_id', $user_id)->where('test_question_id', $request->input('test_question_id'))->first();
        $attempt = Attempt::find($userAnswer->attempt_id);

        $userAnswer->update([
            'point' => $request->input('point'),
        ]);

        if (!Notification::where('type', 3)->where('user_id', $user_id)->where('subject_id', $attempt->subject_id)->where('attempt_id', $attempt->id)->exists()) {
            Notification::create([
                'type' => 3,
                'user_id' => $user_id,
                'subject_id' => $attempt->subject_id,
                'attempt_id' => $attempt->id,
            ]);
        }

        $userSubject = UserSubject::where('user_id', $user_id)->where('subject_id', $attempt->subject_id)->first();

        $userSubject->update([
            'updated_at' => Carbon::now(),
        ]);

        return true;
    }
}
