<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Subject;
use Illuminate\Http\Request;

class CategoriesController extends Controller
{
    public function index(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.categories.index', [
            'subject' => $subject,
        ]);
    }

    public function create(int $id_subject)
    {
        $subject = Subject::find($id_subject);
        $categories = Category::where('subject_id', $id_subject)->get();

        return view('subjects.categories.create', [
            'subject' => $subject,
            'categories' => $categories,
        ]);
    }

    public function store(Request $request, int $id_subject)
    {
        $request->validate([
            'name' => 'required|string',
            'parent_category_id' => 'required|integer'
        ]);

        $category = Category::create([
            'name' => $request->input('name'),
            'parent_category_id' => $request->input('parent_category_id'),
            'subject_id' => $id_subject,
        ]);

        return redirect('/subjects/' . $id_subject . '/categories');
    }

    public function edit(int $id_subject, int $id)
    {
        $subject = Subject::find($id_subject);
        $category = Category::find($id);
        $categories = Category::where('subject_id', $id_subject)->get();

        return view('subjects.categories.edit', [
            'subject' => $subject,
            'category' => $category,
            'categories' => $categories,
        ]);
    }

    public function update(Request $request, int $id_subject, int $id)
    {
        $request->validate([
            'name' => 'required|string',
            'parent_category_id' => 'required|integer'
        ]);

        $category = Category::where('id', $id)
            ->update([
                'name' => $request->input('name'),
                'parent_category_id' => $request->input('parent_category_id')
            ]);

        return redirect('/subjects/' . $id_subject . '/categories');
    }

    public function destroy(int $id_subject, int $id)
    {
        $category = Category::find($id);
        $category->delete();

        return redirect()->back();
    }

    public function show(int $id_subject, int $id)
    {
        $subject = Subject::find($id_subject);
        $category = Category::find($id);

        return view('subjects.categories.show', [
            'subject' => $subject,
            'category' => $category,
        ]);
    }
}
