<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\ExamDate;
use App\Models\Notification;
use App\Models\Subject;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ExamDatesController extends Controller
{
    public function index(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.exam-dates.index', [
            'subject' => $subject,
        ]);
    }

    public function create(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.exam-dates.create', [
            'subject' => $subject,
        ]);
    }

    public function store(Request $request, int $id_subject)
    {
        $request->validate([
            'date_start' => 'required|date',
            'date_end' => 'required|date|after:date_start',
            'type' => 'required|integer|min:1|max:2',
            'form' => 'required|integer|min:1|max:2',
            'room' => 'required|string',
            'capacity' => 'required|integer|min:0',
        ]);

        $examDate = ExamDate::create([
            'subject_id' => $id_subject,
            'date_start' => $request->input('date_start'),
            'date_end' => $request->input('date_end'),
            'type' => $request->input('type'),
            'form' => $request->input('form'),
            'room' => $request->input('room'),
            'capacity' => $request->input('capacity'),
            'occupied' => 0,
            'user_id' => Auth::user()->id,
        ]);

        $subject = Subject::find($id_subject);

        foreach ($subject->uncompleteStudents as $student) {
            Notification::create([
                'user_id' => $student->id,
                'subject_id' => $id_subject,
                'type' => 6,
                'attempt_id' => null,
                'exam_date_id' => $examDate->id,
            ]);
        }

        return redirect('/subjects/' . $id_subject . '/exam-dates');
    }

    public function edit(int $id_subject, $id_date)
    {
        $subject = Subject::find($id_subject);
        $examDate = ExamDate::find($id_date);

        return view('subjects.exam-dates.edit', [
            'subject' => $subject,
            'examDate' => $examDate,
        ]);
    }

    public function update(Request $request, int $id_subject, int $id_date)
    {
        $request->validate([
            'date_start' => 'required|date',
            'date_end' => 'required|date|after:date_start',
            'type' => 'required|integer|min:1|max:2',
            'form' => 'required|integer|min:1|max:2',
            'room' => 'required|string',
            'capacity' => 'required|integer|min:0',
        ]);

        $examDate = ExamDate::where('id', $id_date)
            ->update([
                'date_start' => $request->input('date_start'),
                'date_end' => $request->input('date_end'),
                'type' => $request->input('type'),
                'form' => $request->input('form'),
                'room' => $request->input('room'),
                'capacity' => $request->input('capacity'),
            ]);

        return redirect('/subjects/' . $id_subject . '/exam-dates');
    }

    public function destroy(int $id_subject, int $id_date)
    {
        $date = ExamDate::find($id_date);
        $notifications = $date->notifications;

        foreach ($notifications as $notification) {
            $notification->delete();
        }
        $date->delete();

        return redirect()->back();
    }
}
