<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Content;
use App\Models\File;
use App\Models\Menu;
use App\Models\Subject;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class FilesController extends Controller
{
    public function create(int $id_subject, int $id_menu)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);

        return view('subjects.menus.files.create', [
            'subject' => $subject,
            'menu' => $menu,
        ]);
    }

    public function store(Request $request, int $id_subject, int $id_menu)
    {
        $request->validate([
            'name' => 'required|string',
            'description' => 'sometimes|nullable|string',
            'visible' => 'required|integer|min:1|max:2',
            'file' => 'required|mimes:pdf,docx,pptx|max:5000000000',
        ]);

        $position = Content::where('menu_id', $id_menu)->count();

        $content = Content::create([
            'position' => ($position + 1),
            'menu_id' => $id_menu,
            'visible' => $request->input('visible'),
        ]);

        $file = $request->file;

        $path = $file->store('upload');
        $fileName = explode('/', $path);
        $extension = explode('.', $fileName[1]);

        File::create([
            'name' => $request->input('name'),
            'description' => $request->input('description'),
            'filename' => $path,
            'extension' => $extension[1],
            'content_id' => $content->id,
        ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu);
    }

    public function destroy(int $id_subject, int $id_menu, int $id)
    {
        $file = File::find($id);
        $content = Content::find($file->content_id);

        Storage::delete($file->filename);
        $content->delete();

        return redirect()->back();
    }

    public function edit(int $id_subject, int $id_menu, int $id)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);
        $file = File::find($id);

        return view('subjects.menus.files.edit', [
            'subject' => $subject,
            'menu' => $menu,
            'file' => $file,
        ]);
    }

    public function update(Request $request, int $id_subject, int $id_menu, int $id)
    {
        $request->validate([
            'name' => 'required|string',
            'description' => 'sometimes|nullable|string',
            'visible' => 'required|integer|min:1|max:2',
        ]);

        $file = File::find($id);

        $file->update([
            'name' => $request->input('name'),
            'description' => $request->input('description'),
        ]);

        Content::where('id', $file->content_id)
            ->update([
                'visible' => $request->input('visible'),
            ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu);
    }
}
