<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Lesson;
use App\Models\Setting;
use App\Models\Subject;
use Illuminate\Http\Request;

class LessonsController extends Controller
{
    public function index(int $id_subject)
    {
        $subject = Subject::find($id_subject);
        $setting = Setting::first();
        $colors = ['amber', 'lime', 'cyan', 'violet', 'rose', 'lemon', 'navy', 'viridian'];
        $color = $colors[array_rand($colors)];

        return view('subjects.lessons.index', [
            'subject' => $subject,
            'setting' => $setting,
            'color' => $color,
        ]);
    }

    public function create(int $id_subject)
    {
        $subject = Subject::find($id_subject);
        $setting = Setting::first();

        return view('subjects.lessons.create', [
            'subject' => $subject,
            'setting' => $setting,
        ]);
    }

    public function store(Request $request, int $id_subject)
    {
        $request->validate([
            'day' => 'required|integer|min:1|max:5',
            'start' => 'required|integer|min:1|max:10',
            'length' => 'required|integer|min:1|max:5',
            'type' => 'required|integer|min:1|max:2',
            'user_id' => 'required|integer',
            'room' => 'required|string',
            'capacity' => 'required|integer|min:1',
        ]);

        $start = $request->input('start');
        $length = $request->input('length');
        $end = $start + $length;

        $lesson = Lesson::create([
            'day' => $request->input('day'),
            'start' => $start,
            'end' => $end,
            'type' => $request->input('type'),
            'subject_id' => $id_subject,
            'user_id' => $request->input('user_id'),
            'room' => $request->input('room'),
            'capacity' => $request->input('capacity'),
        ]);

        return redirect('/subjects/' . $id_subject . '/lessons');
    }

    public function edit(int $id_subject, int $id_lesson)
    {
        $subject = Subject::find($id_subject);
        $setting = Setting::first();
        $lesson = Lesson::find($id_lesson);

        return view('subjects.lessons.edit', [
            'subject' => $subject,
            'setting' => $setting,
            'lesson' => $lesson,
        ]);
    }

    public function update(Request $request, int $id_subject, int $id_lesson)
    {
        $request->validate([
            'day' => 'required|integer|min:1|max:5',
            'start' => 'required|integer|min:1|max:10',
            'length' => 'required|integer|min:1|max:5',
            'type' => 'required|integer|min:1|max:2',
            'user_id' => 'required|integer',
            'room' => 'required|string',
            'capacity' => 'required|integer|min:1',
        ]);

        $start = $request->input('start');
        $length = $request->input('length');
        $end = $start + $length;

        $lesson = Lesson::where('id', $id_lesson)
            ->update([
                'day' => $request->input('day'),
                'start' => $start,
                'end' => $end,
                'type' => $request->input('type'),
                'user_id' => $request->input('user_id'),
                'room' => $request->input('room'),
                'capacity' => $request->input('capacity'),
            ]);

        return redirect('/subjects/' . $id_subject . '/lessons');
    }

    public function destroy(int $id_subject, int $id_lesson)
    {
        $lesson = Lesson::find($id_lesson);
        $lesson->delete();

        return redirect()->back();
    }
}
