<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Content;
use App\Models\Menu;
use App\Models\Subject;
use Illuminate\Http\Request;

class MenusController extends Controller
{
    public function create(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.menus.create')->with('subject', $subject);
    }

    public function store(Request $request, int $id_subject)
    {
        $request->validate([
            'name' => 'required|string'
        ]);

        $position = Menu::where('subject_id', $id_subject)->count();

        $menu = Menu::create([
            'name' => $request->input('name'),
            'position' => $position + 1,
            'subject_id' => $id_subject
        ]);

        $content = Content::create([
            'text' => 'Zde můžete vložit popis záložky',
            'position' => 1,
            'menu_id' => $menu->id,
            'visible' => 1,
        ]);

        return redirect('/subjects/' . $id_subject . '/sylabus');
    }

    public function updatePosition(Request $request)
    {
        if ($request->has('id')) {
            $arr = explode(',', $request->input('id'));

            foreach ($arr as $key => $id) {
                $menu = Menu::where('id', $id)->update([
                    'position' => $key + 1
                ]);
            }
            return true;
        }
    }

    public function destroy(int $id_subject, int $id)
    {

        $menu = Menu::find($id);

        if ($menu->content !== null) {
            $menu->content->delete();
        }

        $menu->delete();

        return redirect()->back();
    }

    public function activity(Request $request, int $id_subject, int $id_menu)
    {
        $url = '/subjects/' . $id_subject . '/menus/' . $id_menu . '/';

        switch ($request->input('radio')) {
            case 1:
                $url .= 'files/create';
                break;
            case 2:
                $url .= 'tests/create';
                break;
            case 3:
                $url .= 'homeworks/create';
                break;
            case 4:
                $url .= 'menus/create';
                break;
        }

        return redirect($url);
    }

    public function createContentMenu(int $id_subject, int $id_menu)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);

        return view('subjects.menus.menus.create', [
            'subject' => $subject,
            'menu' => $menu,
        ]);
    }

    public function storeContentMenu(Request $request, int $id_subject, int $id_menu)
    {
        $request->validate([
            'name' => 'required|string',
            'visible' => 'required|integer|min:1|max:2',
        ]);

        $position = Content::where('menu_id', $id_menu)->count();

        $content = Content::create([
            'menu_id' => $id_menu,
            'position' => ($position + 1),
            'visible' => $request->input('visible'),
        ]);

        $menu = Menu::create([
            'name' => $request->input('name'),
            'position' => null,
            'subject_id' => null,
            'content_id' => $content->id,
        ]);

        $content = Content::create([
            'text' => 'Zde můžete vložit popis záložky',
            'position' => 1,
            'menu_id' => $menu->id,
            'visible' => 1,
        ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu);
    }

    public function editContentMenu(int $id_subject, int $id_sidemenu, int $id_menu)
    {
        $subject = Subject::find($id_subject);
        $sidemenu = Menu::find($id_sidemenu);
        $menu = Menu::find($id_menu);

        return view('subjects.menus.menus.edit', [
            'subject' => $subject,
            'sidemenu' => $sidemenu,
            'menu' => $menu,
        ]);
    }

    public function updateContentMenu(Request $request, int $id_subject, int $id_menu, int $id)
    {
        $request->validate([
            'name' => 'required|string',
            'visible' => 'required|integer|min:1|max:2',
        ]);

        $menu = Menu::find($id);

        $menu->update([
            'name' => $request->input('name'),
        ]);

        Content::where('id', $menu->content->id)
            ->update([
                'visible' => $request->input('visible'),
            ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu);
    }
}
