<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Answer;
use App\Models\Category;
use App\Models\Question;
use App\Models\Subject;
use App\Models\Test;
use App\Models\TestQuestion;
use App\Rules\ArrayAtLeastArequired;
use App\Rules\OneMustBeTrue;
use Illuminate\Http\Request;

class QuestionsController extends Controller
{
    public function create(int $id_subject, int $id_category)
    {
        $subject = Subject::find($id_subject);
        $category = Category::find($id_category);

        if ($_GET['type'] === '1') {
            $count = 4;
        } else {
            $count = 1;
        }

        return view('subjects.categories.questions.create', [
            'subject' => $subject,
            'category' => $category,
            'count' => $count,
        ]);
    }

    public function store(Request $request, int $id_subject, int $id_category)
    {
        $validate = [
            'name' => 'required|string',
            'type' => 'required|integer',
            'task' => 'required|string',
        ];

        $type = $_GET['type'];

        if ($type === '1') {
            $validate += [
                'answer' => new ArrayAtLeastArequired(3),
                'answer.*' => 'sometimes|nullable|string',
                'grades' => new OneMustBeTrue(),
                'grades.*' => 'required|integer',
            ];
        } elseif ($type === '2') {
            $validate += [
                'answer' => 'required|integer|min:1|max:2',
            ];
        } elseif ($type === '3') {
            $validate += [
                'answer' => new ArrayAtLeastArequired(1),
                'answer.*' => 'sometimes|nullable|string',
            ];
        }

        $request->validate($validate);

        $question = Question::create([
            'name' => $request->input('name'),
            'type' => $type,
            'task' => $request->input('task'),
            'category_id' => $id_category,
            'random' => null,
        ]);


        if ($type === '1') {
            $grades = $request->input('grades');

            foreach ($request->input('answer') as $key => $answer) {
                if ($answer !== null) {
                    Answer::create([
                        'answer' => $answer,
                        'question_id' => $question->id,
                        'isRight' => $grades[$key],
                    ]);
                }
            }

        } elseif ($type === '2') {
            $answer = $request->input('answer');
            Answer::create([
                'answer' => $answer,
                'question_id' => $question->id,
                'isRight' => 1,
            ]);
        } elseif ($type === '3') {
            foreach ($request->input('answer') as $answer) {
                if ($answer !== null) {
                    Answer::create([
                        'answer' => $answer,
                        'question_id' => $question->id,
                        'isRight' => 1,
                    ]);
                }
            }
        }

        return redirect('/subjects/' . $id_subject . '/categories/' . $id_category);
    }

    public function edit(int $id_subject, int $id_category, int $id)
    {
        $subject = Subject::find($id_subject);
        $category = Category::find($id_category);
        $question = Question::find($id);
        $count = count($question->answers);

        return view('subjects.categories.questions.edit', [
            'subject' => $subject,
            'category' => $category,
            'question' => $question,
            'count' => $count,
        ]);
    }

    public function update(Request $request, int $id_subject, int $id_category, int $id)
    {

        $question = Question::find($id);

        $validate = [
            'name' => 'required|string',
            'task' => 'required|string',
        ];

        $type = $question->type;

        if ($type === 1) {
            $validate += [
                'answer' => new ArrayAtLeastArequired(3),
                'answer.*' => 'sometimes|nullable|string',
                'grades' => new OneMustBeTrue(),
                'grades.*' => 'required|integer',
            ];
        } elseif ($type === 2) {
            $validate += [
                'answer' => 'required|integer|min:1|max:2',
            ];
        } elseif ($type === 3) {
            $validate += [
                'answer' => new ArrayAtLeastArequired(1),
                'answer.*' => 'sometimes|nullable|string',
            ];
        }
        $request->validate($validate);

        $question->update([
            'name' => $request->input('name'),
            'task' => $request->input('task'),
            'random' => null,
        ]);

        if ($type === 1 || $type === 3) {
            $countAnswer = count($question->answers);
            $countNewAnswer = 0;
            foreach ($request->input('answer') as $answer) {
                if ($answer !== null) {
                    $countNewAnswer++;
                }
            }

            foreach ($request->input('answer') as $key => $answer) {
                $id = $question->answers[$key - 1]->id;
                if ($answer !== null) {
                    if ($type === 1) {
                        $grades = $request->input('grades');
                        if ($countNewAnswer <= $countAnswer) {
                            Answer::where('id', $id)->update([
                                'answer' => $answer,
                                'isRight' => $grades[$key],
                            ]);
                        } elseif ($countNewAnswer > $countAnswer) {
                            Answer::create([
                                'answer' => $answer,
                                'isRight' => $grades[$key],
                            ]);
                        }
                    } else {
                        if ($countNewAnswer <= $countAnswer) {
                            Answer::where('id', $id)->update([
                                'answer' => $answer,
                                'isRight' => 1,
                            ]);
                        } elseif ($countNewAnswer > $countAnswer) {
                            Answer::create([
                                'answer' => $answer,
                                'isRight' => 1,
                            ]);
                        }
                    }

                }
            }
        } elseif ($type === 2) {
            Answer::where('id', $id)->update([
                'answer' => $request->input('answer'),
            ]);
        }

        return redirect('/subjects/' . $id_subject . '/categories/' . $id_category);
    }

    public function show(int $id_subject, int $id_category, int $id)
    {
        $subject = Subject::find($id_subject);
        $category = Category::find($id_category);
        $question = Question::find($id);

        return view('subjects.categories.questions.show', [
            'subject' => $subject,
            'category' => $category,
            'question' => $question,
        ]);
    }

    public function check(Request $request, int $id_subject, int $id_category, int $id)
    {
        $request->validate([
            'answer' => 'nullable|sometimes'
        ]);

        $subject = Subject::find($id_subject);
        $category = Category::find($id_category);
        $question = Question::find($id);

        $answer = $request->input('answer');
        $rightFeedback = 'Ano, vaše odpověď je správná';
        $almostRightFeedback = 'Vaše odpověď je částečně správná';
        $badFeedback = 'Ne, vaše odpověď je špatná';

        $right = 2;
        $feedback = $badFeedback;
        $countOfAnswers = count($question->answersRight);

        if ($question->type === 1) {
            if ($countOfAnswers === 1) {
                if ($question->answersRight[0]->id == $answer) {
                    $right = 1;
                    $feedback = $rightFeedback;
                }
            } elseif ($countOfAnswers > 1) {
                $count = 0;
                foreach ($answer as $ans) {
                    $i = 0;
                    foreach ($question->answersRight as $rightAnswer) {
                        if ($ans == $rightAnswer->id) {
                            $i++;
                        }
                    }
                    if ($i === 1) {
                        $count++;
                    } else {
                        $count--;
                    }
                }

                if ($count === $countOfAnswers) {
                    $right = 1;
                    $feedback = $rightFeedback;
                } elseif ($count < $countOfAnswers && $count > 0) {
                    $right = 1;
                    $feedback = $almostRightFeedback;
                } elseif ($count <= 0) {
                    $right = 2;
                    $feedback = $badFeedback;
                }
            }
        } elseif ($question->type === 2) {
            if ($question->answers[0]->answer == $answer) {
                $right = 1;
                $feedback = $rightFeedback;
            }
        } elseif ($question->type === 3) {
            foreach ($question->answersRight as $answerRight) {
                if ($answerRight->answer === $answer) {
                    $right = 1;
                    $feedback = $rightFeedback;
                    continue;
                }
            }
        }

        return view('subjects.categories.questions.show', [
            'subject' => $subject,
            'category' => $category,
            'question' => $question,
            'feedback' => $feedback,
            'right' => $right,
            'answerFeedback' => $answer,
            'rightAnswers' => $question->answersRight,
        ]);
    }

    public function delete(Request $request, int $id_subject, int $id_category)
    {
        $questions = $request->input('questions');

        if ($questions != null) {
            foreach ($questions as $question) {
                $question = Question::find($question);
                $question->delete();
            }
        }

        return redirect()->back();
    }

    public function type(Request $request, int $id_subject, int $id_category)
    {
        $value = $request->input('radio');
        return redirect('/subjects/' . $id_subject . '/categories/' . $id_category . '/questions/create?type=' . $value);
    }

    public function updatePosition(Request $request)
    {
        if ($request->has('id')) {
            $arr = explode(',', $request->input('id'));

            foreach ($arr as $key => $id) {
                $question = TestQuestion::where('id', $id)->update([
                    'position' => $key + 1
                ]);
            }
            return true;
        }
    }

    public function updatePoint(Request $request)
    {
        $testQuestion = TestQuestion::find($request->input('id'));

        $testQuestion->update([
            'point' => $request->input('point')
        ]);

        $test = Test::find($testQuestion->test_id);

        $points = 0;

        foreach ($test->questions as $question) {
            $points += $question->pivot->point;
        }

        $test->update([
            'points' => $points,
        ]);

        return true;
    }

}
