<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Lesson;
use App\Models\Setting;
use App\Models\Subject;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class SubjectsController extends Controller
{
    public function students($id_subject)
    {
        $subject = Subject::find($id_subject);
        $students = $subject->students;
        $setting = Setting::first();

        foreach ($students as $student) {
            $student->classification = $student->classification->where('subject_id', $subject->id)->first();
        }

        return view('subjects.students.index', compact('subject', 'students', 'setting'));
    }

    public function edit(int $id_subject)
    {
        $subject = Subject::find($id_subject);

        return view('subjects.edit', [
            'subject' => $subject,
        ]);
    }

    public function update(Request $request, int $id_subject)
    {
        $request->validate([
            'sylabus' => 'required|string',
        ]);

        $subject = Subject::where('id', $id_subject)
            ->update([
                'sylabus' => $request->input('sylabus'),
            ]);

        return redirect('/subjects/' . $id_subject . '/sylabus');
    }

    public function search(Request $request, int $id_subject)
    {
        if ($request->ajax()) {
            $search = $request->get('query');
            $lesson = $request->get('select');
            $search = str_replace(" ", "%", $search);
            $subject = Subject::find($id_subject);


            if (empty($lesson) || $lesson === '0') {
                $students = User::whereExists(function ($query) use ($id_subject) {
                    $query->select(DB::raw(1))
                        ->from('users_subjects')
                        ->whereColumn('users_subjects.user_id', 'users.id')
                        ->where('subject_id', $id_subject);
                })->where(function ($query) use ($search) {
                    $query->
                    where(DB::raw('concat(firstname," ",lastname)'), 'like', '%' . $search . '%')
                        ->orWhere('lastname', 'LIKE', '%' . $search . '%')
                        ->orWhere('firstname', 'LIKE', '%' . $search . '%')
                        ->orWhere('username', 'LIKE', '%' . $search . '%')
                        ->orWhere('email', 'LIKE', '%' . $search . '%');
                })->where('authorization', 3)->orderBy('lastname')->paginate(20);
            } else {
                $lesson = Lesson::find($lesson);

                $students = User::whereExists(function ($query) use ($lesson) {
                    $query->select(DB::raw(1))
                        ->from('users_lessons')
                        ->whereColumn('users_lessons.user_id', 'users.id')
                        ->where('lesson_id', $lesson->id);
                })->where(function ($query) use ($search) {
                    $query->
                    where(DB::raw('concat(firstname," ",lastname)'), 'like', '%' . $search . '%')
                        ->orWhere('lastname', 'LIKE', '%' . $search . '%')
                        ->orWhere('firstname', 'LIKE', '%' . $search . '%')
                        ->orWhere('username', 'LIKE', '%' . $search . '%')
                        ->orWhere('email', 'LIKE', '%' . $search . '%');
                })->where('authorization', 3)->orderBy('lastname')->paginate(20);
            }

            foreach ($students as $student) {
                $student->classification = $student->classification->where('subject_id', $subject->id)->first();
            }

            return view('subjects.students.list', compact('students', 'subject'))->render();
        }
    }
}
