<?php

namespace App\Http\Controllers\Teacher;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Content;
use App\Models\Menu;
use App\Models\Question;
use App\Models\Subject;
use App\Models\Test;
use App\Models\TestQuestion;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class TestsController extends Controller
{
    public function create(int $id_subject, int $id_menu)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);

        return view('subjects.menus.tests.create', [
            'subject' => $subject,
            'menu' => $menu,
        ]);
    }

    public function store(Request $request, int $id_subject, int $id_menu)
    {
        $seconds = ($request->input('time') * $request->input('units')) - 60;
        $dateEnd = Carbon::parse($request->input('date_start'))
            ->addSeconds($seconds)
            ->format('Y-m-d\TH:i');

        $validate = [
            'name' => 'required|string',
            'description' => 'sometimes|nullable|string',
            'type' => 'required|integer|min:1|max:3',
            'random' => 'required|integer|min:1|max:2',
            'visible' => 'required|integer|min:1|max:2',
        ];

        if ($request->input('type') === '1') {
            $validate += [
                'time' => 'sometimes|nullable|integer',
            ];
            $password = null;
        } else {
            $validate += [
                'password' => 'required|string',
                'date_start' => 'required|date',
                'date_end' => 'required|date|after:' . $dateEnd,
                'time' => 'required|integer',
            ];
            $password = Hash::make($request->input('password'));
        }

        $request->validate($validate);

        $position = Content::where('menu_id', $id_menu)->count();

        $content = Content::create([
            'position' => ($position + 1),
            'menu_id' => $id_menu,
            'visible' => $request->input('visible'),
        ]);

        Test::create([
            'name' => $request->input('name'),
            'description' => $request->input('description'),
            'password' => $password,
            'type' => $request->input('type'),
            'random' => $request->input('random'),
            'date_start' => $request->input('date_start'),
            'date_end' => $request->input('date_end'),
            'time' => ($request->input('time') * $request->input('units')),
            'content_id' => $content->id,
            'points' => 0,
        ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu);
    }

    public function edit(int $id_subject, int $id_menu, int $id)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);
        $test = Test::find($id);

        return view('subjects.menus.tests.edit', [
            'subject' => $subject,
            'menu' => $menu,
            'test' => $test,
        ]);
    }

    public function update(Request $request, int $id_subject, int $id_menu, int $id)
    {
        $seconds = ($request->input('time') * $request->input('units')) - 60;
        $dateEnd = Carbon::parse($request->input('date_start'))
            ->addSeconds($seconds)
            ->format('Y-m-d\TH:i');

        $validate = [
            'name' => 'required|string',
            'description' => 'sometimes|nullable|string',
            'type' => 'required|integer|min:1|max:3',
            'random' => 'required|integer|min:1|max:2',
            'visible' => 'required|integer|min:1|max:2',
        ];

        if ($request->input('type') === '1') {
            $validate += [
                'time' => 'sometimes|nullable|integer',
            ];
        } else {
            $validate += [
                'password' => 'required|string',
                'date_start' => 'required|date',
                'date_end' => 'required|date|after:' . $dateEnd,
                'time' => 'required|integer',
            ];
        }

        $request->validate($validate);

        $test = Test::find($id);

        $test->update([
            'name' => $request->input('name'),
            'description' => $request->input('description'),
            'password' => Hash::make($request->input('password')),
            'type' => $request->input('type'),
            'random' => $request->input('random'),
            'date_start' => $request->input('date_start'),
            'date_end' => $request->input('date_end'),
            'time' => ($request->input('time') * $request->input('units')),
        ]);

        Content::where('id', $test->content_id)
            ->update([
                'visible' => $request->input('visible'),
            ]);

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu);
    }

    public function destroy(int $id_subject, int $id_menu, int $id)
    {
        $test = Test::find($id);
        $content = Content::find($test->content_id);

        $content->delete();
        $test->delete();

        return redirect()->back();
    }

    public function testQuestions(int $id_subject, int $id_menu, int $id)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);
        $test = Test::find($id);

        return view('subjects.menus.tests.questions', [
            'subject' => $subject,
            'menu' => $menu,
            'test' => $test,
        ]);
    }

    public function categoryQuestions(int $id_subject, int $id_menu, int $id_test)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);
        $test = Test::find($id_test);
        $category = Category::where('subject_id', $id_subject)->where('parent_category_id', null)->first();

        $questions = Question::where('category_id', $category->id)->whereNotExists(function ($query) use ($id_test) {
            $query->select(DB::raw(1))
                ->from('tests_questions')
                ->whereRaw('questions.id = tests_questions.question_id')
                ->where('tests_questions.test_id', $id_test);
        })->get();

        return view('subjects.menus.tests.questions-add', [
            'subject' => $subject,
            'menu' => $menu,
            'test' => $test,
            'questions' => $questions,
        ]);
    }

    public function search(Request $request, int $id_subject, int $id_menu, int $id_test)
    {
        if ($request->ajax()) {
            $category = $request->get('select');

            $category = Category::find($category);

            $questions = Question::where('category_id', $category->id)->whereNotExists(function ($query) use ($id_test) {
                $query->select(DB::raw(1))
                    ->from('tests_questions')
                    ->whereRaw('questions.id = tests_questions.question_id')
                    ->where('tests_questions.test_id', $id_test);
            })->get();

            return view('subjects.menus.tests.list', compact('questions'))->render();
        }
    }

    public function addQuestions(Request $request, int $id_subject, int $id_menu, int $id)
    {
        $questions = $request->input('questions');

        if ($questions != null) {
            foreach ($questions as $question) {
                $position = TestQuestion::where('test_id', $id)->count();

                $testQuestion = TestQuestion::create([
                    'test_id' => $id,
                    'question_id' => $question,
                    'position' => $position + 1,
                    'point' => 0,
                ]);
            }
        }

        return redirect('/subjects/' . $id_subject . '/menus/' . $id_menu . '/tests/' . $id . '/questions');
    }

    public function deleteQuestions(Request $request, int $id_subject, int $id_menu, int $id_test)
    {
        $questions = $request->input('questions');

        if ($questions != null) {
            foreach ($questions as $question) {
                $question = TestQuestion::where('question_id', $question)->where('test_id', $id_test)->first();
                $question->delete();
            }
        }

        return redirect()->back();
    }

    public function attempts(int $id_subject, int $id_menu, int $id_test)
    {
        $subject = Subject::find($id_subject);
        $menu = Menu::find($id_menu);
        $test = Test::find($id_test);

        return view('subjects.menus.tests.attempts', [
            'subject' => $subject,
            'menu' => $menu,
            'test' => $test,
        ]);
    }
}
