<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Subject extends Model
{
    use HasFactory;

    protected $table = 'subjects';

    protected $primaryKey = 'id';

    protected $fillable = [
        'name',
        'shortname',
        'study_year',
        'semester',
        'examination',
        'credits',
        'sylabus',
    ];

    public $timestamps = false;

    public function menus(){
        return $this->hasMany(Menu::class)->orderBy('position');
    }

    public function categories(){
        return $this->hasMany(Category::class);
    }

    public function category(){
        return $this->hasOne(Category::class)->where('parent_category_id', NULL);
    }

    public function teachers(){
        return $this->belongsToMany(User::class, UserSubject::class)->where('authorization', 2)->orderBy('lastname');
    }

    public function students(){
        return $this->belongsToMany(User::class, UserSubject::class)->where('authorization', 3)->orderBy('lastname');
    }

    public function uncompleteStudents(){
        return $this->belongsToMany(User::class, UserSubject::class)->where('authorization', 3)->withPivot('completed')->where('completed', 0)->orderBy('lastname');
    }

    public function dates(){
        return $this->hasMany(ExamDate::class)->where('date_start', '>' , Carbon::now())->orderBy('date_start');
    }

    public function examDates(){
        return $this->hasMany(ExamDate::class)->where('date_start', '>' , Carbon::now())->where(function ($query){
            $query->where('type', 3)->orWhere('type', 4);
        })->orderBy('date_start');
    }

    public function creditDates(){
        return $this->hasMany(ExamDate::class)->where('date_start', '>' , Carbon::now())->where(function ($query){
            $query->where('type', 1)->orWhere('type', 2);
        })->orderBy('date_start');
    }

    public function lessons(){
        return $this->hasMany(Lesson::class);
    }

    public function lectures(){
        return $this->hasMany(Lesson::class)->where('type', 1);
    }

    public function practice(){
        return $this->hasMany(Lesson::class)->where('type', 2);
    }

    public function attempts(){
        return $this->hasMany(Attempt::class)->orderByDesc('updated_at');
    }
}
