<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;

class User extends Authenticatable
{
    use HasFactory, Notifiable;

    public $timestamp = false;

    protected $table = 'users';

    protected $primaryKey = 'id';

    protected $fillable = [
        'firstname',
        'lastname',
        'username',
        'email',
        'password',
        'study_year',
        'authorization',
        'credits',
        'field_id',
    ];

    protected $hidden = [
        'password',
    ];

    public function field()
    {
        return $this->hasOne(Field::class, 'id', 'field_id');
    }

    public function subjects()
    {
        return $this->belongsToMany(Subject::class, UserSubject::class)->withPivot('enroll', 'completed', 'attempts')->orderBy('name');
    }

    public function subjectsClassification()
    {
        return $this->belongsToMany(Subject::class, UserSubject::class)->withPivot('updated_at')->orderBy('updated_at', 'desc');
    }

    public function completedSubjects()
    {
        return $this->belongsToMany(Subject::class, UserSubject::class)->withPivot('enroll', 'completed', 'attempts')->where('completed', 1)->orderBy('name');
    }

    public function uncompletedSubjects()
    {
        return $this->belongsToMany(Subject::class, UserSubject::class)->withPivot('enroll', 'completed', 'attempts')->where('completed', 0)->orderBy('name');
    }

    public function examDates()
    {
        return $this->belongsToMany(ExamDate::class, UserExamDate::class)->where('date_start', '>' , Carbon::now());
    }

    public function teacherExamDates()
    {
        return $this->hasMany(ExamDate::class)->where('date_start', '>' , Carbon::now());
    }

    public function classification()
    {
        return $this->hasMany(Classification::class);
    }

    public function notifications()
    {
        return $this->hasMany(Notification::class);
    }

    public function attempts()
    {
        return $this->hasMany(Attempt::class)->orderBy('updated_at');
    }

    public function preregistration()
    {
        return $this->belongsToMany(Lesson::class, Preregistration::class);
    }

    public function lessons()
    {
        return $this->belongsToMany(Lesson::class, UserLesson::class);
    }

    public function teacherLessons()
    {
        return $this->hasMany(Lesson::class);
    }

    public $timestamps = false;
}
