@extends('layouts.administration')

@section('title', 'Nastavení')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Nastavení</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form class="w-full space-y-2 sm:space-y-4" action="/admin/settings/{{ $setting->id }}" method="POST">
            @csrf
            @method('put')

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Název:</span>
                <input name="name" type="text"
                       class="@error('name') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{ old('name', $setting->name) }}">
                @error('name')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Zkratka:</span>
                <input name="shortname" type="text"
                       class="@error('shortname') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                value="{{ old('shortname', $setting->shortname) }}">
                @error('shortname')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Doména e-mailu:</span>
                <input name="mail" type="text"
                       class="@error('mail') border-red-500 @enderror form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200"
                       value="{{ old('mail', $setting->email) }}">
                @error('mail')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <h5 class="font-semibold mt-4">Nastavení testů:</h5>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Číslování:</span>
                <select name="numbering"
                        class="@error('numbering') border-red-500 @enderror form-select block w-full mt-2 focus:shadow-outline-gray border border-gray-200">
                    <option value="1" {{ (old('numbering', $setting->numbering) == 1) ? 'selected' : '' }}>Nečíslovat</option>
                    <option value="2" {{ (old('numbering', $setting->numbering) == 2) ? 'selected' : '' }}>A. B. C.</option>
                    <option value="3" {{ (old('numbering', $setting->numbering) == 3) ? 'selected' : '' }}>1. 2. 3.</option>
                </select>
                @error('numbering')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Stránkování:</span>
                <select name="pagination"
                        class="@error('pagination') border-red-500 @enderror form-select block w-full mt-2 focus:shadow-outline-gray border border-gray-200">
                    <option value="1" {{ (old('pagination', $setting->pagination) == 1) ? 'selected' : '' }}>Všechný úlohy na jednu
                        stránku
                    </option>
                    <option value="2" {{ (old('pagination', $setting->pagination) == 2) ? 'selected' : '' }}>Každá úloha na vlastní
                        stránku
                    </option>
                </select>
                @error('pagination')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <h5 class="font-semibold mt-4">Tvorba uživatelského jména:</h5>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Počet písmen z jména:</span>
                <input name="firstname" type="number"
                       class="@error('firstname') border-red-500 @enderror form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200"
                       value="{{ old('firstname', $setting->firstname )}}">
                @error('firstname')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Počet písmen z příjmení:</span>
                <input name="lastname" type="number"
                       class="@error('lastname') border-red-500 @enderror form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200"
                       value="{{ old('lastname', $setting->lastname )}}">
                @error('lastname')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <h5 class="font-semibold mt-4">Nastavení rozvrhu:</h5>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Čas první hodiny</span>
                <input name="start" type="time"
                       value="{{ old('start', \Carbon\Carbon::parse($setting->start)->format('h:i')) }}"
                       class="start @error('start') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('start')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum předzápisu</span>
                <input name="preregistration" type="datetime-local"
                       value="{{ old('preregistration', \Carbon\Carbon::parse($setting->preregistration)->format('Y-m-d\TH:i')) }}"
                       class="date_start @error('preregistration') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('preregistration')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum zápisu</span>
                <input name="registration" type="datetime-local"
                       value="{{ old('registration', \Carbon\Carbon::parse($setting->registration)->format('Y-m-d\TH:i')) }}"
                       class="date_start @error('registration') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('registration')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum konce zápisu</span>
                <input name="end_registration" type="datetime-local"
                       value="{{ old('end_registration', \Carbon\Carbon::parse($setting->end_registration)->format('Y-m-d\TH:i')) }}"
                       class="date_start @error('end_registration') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('end_registration')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span
                    class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Počet pokusů na dokončení předmětu:</span>
                <input name="attempts" type="number"
                       class="@error('attempts') border-red-500 @enderror form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200"
                       value="{{ old('attempts', $setting->attempts) }}">
                @error('attempts')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <h5 class="font-semibold mt-4">Nastavení semestrů:</h5>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Začátek zimního semestru</span>
                <input name="first_semester_start" type="date"
                       value="{{ old('first_semester_start', \Carbon\Carbon::parse($setting->first_semester_start)->format('Y-m-d')) }}"
                       class="date_start @error('first_semester_start') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('first_semester_start')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Konec zimního semestru</span>
                <input name="first_semester_end" type="date"
                       value="{{ old('first_semester_end', \Carbon\Carbon::parse($setting->first_semester_end)->format('Y-m-d')) }}"
                       class="date_start @error('first_semester_end') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('first_semester_end')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Začátek letního semestru</span>
                <input name="second_semester_start" type="date"
                       value="{{ old('second_semester_start', \Carbon\Carbon::parse($setting->second_semester_start)->format('Y-m-d')) }}"
                       class="date_start @error('second_semester_start') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('second_semester_start')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Konec letního semestru</span>
                <input name="second_semester_end" type="date"
                       value="{{ old('second_semester_end', \Carbon\Carbon::parse($setting->second_semester_end)->format('Y-m-d')) }}"
                       class="date_start @error('second_semester_end') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('second_semester_end')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit"
                    class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                Upravit
            </button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('admin.settings.edit') }}
@endsection
