@extends('layouts.administration')

@section('title', $user->lastname . ' ' . $user->firstname)

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">{{ $user->lastname . ' ' . $user->firstname }}</h2>

    <div class="grid grid-flow-row grid-cols-5 md:grid-cols-10 pt-2 md:pt-5">
        <div class="col-span-4 pt-2 md:pt-0">
            <h3 class="text-xl font-semibold uppercase tracking-wider">Osobní údaje:</h3>
            <div class="overflow-x-auto">
                <table class="w-full text-center mt-5">
                    <tr>
                        <th class="py-2 px-5 md:px-0">Login:</th>
                        <td class="py-2 px-5 md:px-0">{{ $user->username }}</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">E-mail:</th>
                        <td class="py-2 px-5 md:px-0">{{ $user->email }}</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Obor:</th>
                        <td class="py-2 px-5 md:px-0">{{ $user->field->name }}</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Odstudováno:</th>
                        @php
                            $now = \Carbon\Carbon::now();
                            $register = new \Carbon\Carbon($user->study_year);
                            $register = $register->diff($now)->days;
                        @endphp
                        <td class="py-2 px-5 md:px-0">{{ $register }} dní</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Kredity:</th>
                        <td class="py-2 px-5 md:px-0">{{ $user->completedSubjects->sum('credits') . '/' . $user->field->credits }}</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Plánované kredity:</th>
                        <td class="py-2 px-5 md:px-0">{{ $user->uncompletedSubjects->sum('credits') }}</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Splněné předměty:</th>
                        <td class="py-2 px-5 md:px-0">{{ $user->completedSubjects->count() . '/' . $user->field->subjects->count() }}</td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Upravit:</th>
                        <td class="py-2 px-5 md:px-0">
                            <a href="{{ $user->id }}/edit"
                               class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">Upravit</a>
                        </td>
                    </tr>
                    <tr>
                        <th class="py-2 px-5 md:px-0">Odstranit:</th>
                        <td class="py-2 px-5 md:px-0">
                            <form action="{{ $user->id }}" method="POST">
                                @csrf
                                @method('delete')
                                <button
                                    class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">
                                    Odstranit
                                </button>
                            </form>
                        </td>
                    </tr>
                </table>
            </div>
        </div>

        @if($user->subjects->count() > 0 && $user->authorization === 3)
            @php
                $text = ['A', 'B', 'C', 'D', 'E', 'F']
            @endphp
            <div class="col-span-6 pt-2 md:pt-0">
                <h3 class="text-xl font-semibold uppercase tracking-wider">Klasifikace:</h3>
                <select name="year" id="filter"
                        class=" filter form-select block w-full mt-2 border border-gray-200">
                    <option value="1">1. ročník</option>
                    <option value="2">2. ročník</option>
                    <option value="3">3. ročník</option>
                </select>

                <div class="overflow-x-auto">
                    <table class="w-full text-center mt-5">
                        <thead>
                        <tr>
                            <th class="py-2 px-5 md:px-0">Název</th>
                            <th class="py-2 px-5 md:px-0">Zkratka</th>
                            <th class="py-2 px-5 md:px-0">Kredity</th>
                            <th class="py-2 px-5 md:px-0">Zkouška</th>
                            <th class="py-2 px-5 md:px-0">Zápočet</th>
                        </tr>
                        </thead>
                        @foreach($user->subjects as $subject)
                            @php
                                $classification = \App\Models\Classification::where('subject_id', $subject->id)->where('user_id', $user->id)->first();
                            @endphp
                            <tr class="{{ (($subject->pivot->completed === 2) ? 'bg-red-400' : '') . (($subject->pivot->completed === 1) ? 'bg-green-400' : '') }}">
                                <td class="py-2">{{ $subject->name }}</td>
                                <td class="py-2">{{ $subject->shortname }}</td>
                                <td class="py-2">{{ $subject->credits }}</td>
                                <td class="py-2">{{ ($classification !== null && $classification->exam !== null) ? $text[$classification->exam] : '-' }}</td>
                                <td class="py-2">{{ ($classification !== null) ? $text[$classification->credit] : '-' }}</td>
                            </tr>
                        @endforeach
                    </table>
                </div>
            </div>
        @endif
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('admin.students.show', $user) }}
@endsection
