@extends('layouts.administration')

@section('title', 'Upravit předmět')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Upravit předmět</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form class="w-full space-y-2 sm:space-y-4" action="/admin/subjects/{{ $subject->id }}" method="POST">
            @csrf
            @method('put')
            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Název:</span>
                <input name="name" type="text"
                       class="@error('name') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{old('name', $subject->name)}}">
                @error('name')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Zkratka:</span>
                <input name="shortname" type="text"
                       class="@error('shortname') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{old('shortname', $subject->shortname)}}">
                @error('shortname')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Ročník:</span>
                <select name="study_year"
                        class="@error('study_year') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('study_year', $subject->study_year) == 1) ? 'selected' : '' }}>1. ročník</option>
                    <option value="2" {{ (old('study_year', $subject->study_year) == 2) ? 'selected' : '' }}>2. ročník</option>
                    <option value="3" {{ (old('study_year', $subject->study_year) == 3) ? 'selected' : '' }}>3. ročník</option>
                </select>
                @error('study_year')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Semestr:</span>
                <select name="semester"
                        class="@error('semester') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('semester', $subject->semester) == 1) ? 'selected' : '' }}>Zimní semester</option>
                    <option value="2" {{ (old('semester', $subject->semester) == 2) ? 'selected' : '' }}>Letní semester</option>
                </select>
                @error('semester')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Ukončení:</span>
                <select name="examination"
                        class="@error('examination') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('examination', $subject->examination) == 1) ? 'selected' : '' }}>Zápočet</option>
                    <option value="2" {{ (old('examination', $subject->examination) == 2) ? 'selected' : '' }}>Zápočet + zkouška</option>
                </select>
                @error('examination')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Kredity:</span>
                <input name="credits" type="number"
                       class="@error('credits') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{old('credits', $subject->credits)}}">
                @error('credits')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Sylabus:</span>
                <div class="mt-2">
                    <textarea class="form-control" id="summary-ckeditor" name="sylabus">{!! old('sylabus', $subject->sylabus) !!}</textarea>
                </div>
                @error('sylabus')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                Upravit
            </button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('admin.subjects.edit', $subject) }}
@endsection

@section('scripts')
    <script>
        ClassicEditor
            .create( document.querySelector( '#summary-ckeditor' ) )
            .catch( error => {
                console.error( error );
            } );
    </script>
@endsection
