@extends('layouts.administration')

@section('title', 'Klasifikace')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Klasifikace</h2>

    <div class="mt-10">
        @foreach($subjects as $key => $subject)
            @php
                $classification = $student->classification->where('subject_id', $subject->id)->first();
                $notification = $notifications->where('subject_id', $subject->id);
                $grade = ['?', 'A', 'B', 'C', 'D', 'E', 'F'];
            @endphp
            <div class="w-full bg-white mb-4 rounded shadow">
                <a target="{{ $key }}" subject_id="{{ $subject->id }}"
                   class="show px-4 pt-3 pb-3 grid grid-flow-row grid-cols-6 md:grid-cols-10 font-semibold cursor-pointer text-gray-700 ">
                    <div class="col-span-5">
                        <h4 class="text-xl uppercase tracking-wider hover:text-black hover:underline">{{ $subject->name }}</h4>
                    </div>
                    <div class="text-lg col-span-2">
                        <p>Zkouška: {{ (($classification !== null && $classification->exam !== null) ?
                            $grade[$classification->exam] : '?') }}</p>
                    </div>
                    <div class="text-lg col-span-2">
                        <p>Zápočet: {{ (($classification !== null && $classification->credit !== null) ?
                            $grade[$classification->credit] : '?') }}</p>
                    </div>
                    <div class="text-lg col-span-1 flex justify-end">
                        @if($notification->count() > 0)
                            <div class="flex justify-center items-center w-7 h-7 border border-red-600 bg-red-600 rounded-full">
                                <span class="text-white">{{ $notifications->where('type', '<', 4)->count() }}</span>
                            </div>
                        @endif
                    </div>
                </a>

                <div id="div{{ $key }}" hidden class="pb-5 px-4">
                    <div class="overflow-x-auto">
                        <table class="w-full text-center pt-5">
                            <tr>
                                <th class="py-5 px-5 md:px-0">Klasifikováno</th>
                                <th class="py-5 px-5 md:px-0">Název testu</th>
                                <th class="py-5 px-5 md:px-0">Body</th>
                                <th class="py-5 px-5 md:px-0">Poznámka</th>
                            </tr>
                            @foreach($subject->attempts as $attempt)
                                @php
                                    $attemptsNotification = $notification->where('attempt_id', $attempt->id);
                                @endphp
                                <tr class="border-b border-gray-400 {{ ($attemptsNotification->count() > 0) ? 'bg-red-500 bg-opacity-60' : '' }}">
                                    <td class="py-2">{{ $attempt->updated_at->isoFormat('LLL') }}</td>
                                    <td class="py-2">{{ $attempt->name }}</td>
                                    <td class="py-2">{{ $attempt->points . '/' . $attempt->max_points }}</td>
                                    <td class="py-2">{{ \Illuminate\Support\Str::limit($attempt->text, 20) }}</td>
                                </tr>
                            @endforeach
                        </table>
                    </div>
                </div>
            </div>
        @endforeach
    </div>
    <div>
        {{ $subjects->links() }}
    </div>

@endsection

@section('scripts')
    <script>
        $(document).ready(function () {

            $('.show').click(function () {
                let div = $('#div' + $(this).attr('target'));
                let id = $(this).attr('subject_id');
                if (div.is(':hidden')) {
                    div.show(400);
                    deleteNotifications(id);
                } else {
                    div.hide(400);
                }
            });

            function deleteNotifications(id) {
                $.ajax({
                    url: '{{ route('student.notifications.destroy') }}',
                    method: 'GET',
                    data: {
                        id:id,
                        type:1,
                    },
                    dataType: 'json',
                    success: function (data) {

                    }
                })
            }
        })
    </script>
@endsection


@section('breadcrumbs')
    {{ Breadcrumbs::render('student.classification') }}
@endsection
