@extends('layouts.administration')

@section('title', 'Zápis termínů')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Zápis termínů</h2>

    <div class="mt-10">
        @foreach($subjects as $key => $subject)
            @php
                $notification = $notifications->where('subject_id', $subject->id);
            @endphp
            @if($subject->dates->count() > 0)
                <div class="w-full bg-white mb-4 rounded shadow">
                    <a target="{{ $key }}" subject_id="{{ $subject->id }}"
                       class="show px-4 pt-3 pb-3 grid grid-flow-row grid-cols-10 font-semibold cursor-pointer text-gray-700">
                        <div class="col-span-9">
                            <h4 class="text-xl uppercase tracking-wider hover:text-black hover:underline">{{ $subject->name }}</h4>
                        </div>
                        <div class="text-lg col-span-1 flex justify-end">
                            <div class="flex justify-center items-center w-7 h-7 {{ ($notification->count() > 0) ? 'text-white border border-red-600 bg-red-600 rounded-full' : '' }}">
                                <p class="">{{ $subject->dates->count() }}</p>
                            </div>
                        </div>
                    </a>

                    <div id="div{{ $key }}" hidden class="pb-5 px-4">
                        <div class="overflow-x-auto">
                            <table class="w-full text-center pt-5">
                                <tr>
                                    <th class="py-5 px-5 md:px-0">Typ</th>
                                    <th class="py-5 px-5 md:px-0">Forma</th>
                                    <th class="py-5 px-5 md:px-0">Zkoušející</th>
                                    <th class="py-5 px-5 md:px-0">Datum</th>
                                    <th class="py-5 px-5 md:px-0">Místnost</th>
                                    <th class="py-5 px-5 md:px-0">Kapacita</th>
                                    <th class="py-5 px-5 md:px-0"></th>
                                </tr>
                                @foreach($subject->dates as $date)
                                    <tr class="border-b border-gray-400 {{ ($date->enroll === true) ? 'bg-green-500 bg-opacity-60' : '' }}">
                                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">
                                            @switch($date->type)
                                                @case(1)
                                                Zápočet
                                                @break
                                                @case(2)
                                                Zkouška
                                                @break
                                            @endswitch
                                        </td>
                                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">
                                            @switch($date->form)
                                                @case(1)
                                                Prezenční
                                                @break
                                                @case(2)
                                                Online
                                                @break
                                            @endswitch
                                        </td>
                                        <td class="py-2">{{ $date->user->lastname . " " . $date->user->firstname }}</td>
                                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $date->date_start->isoFormat('LLL') . ' – ' . $date->date_end->isoFormat('LLL') }}</td>
                                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $date->room }}</td>
                                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $date->occupied . '/' . $date->capacity }}</td>
                                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">
                                            @if($date->enroll === true)
                                                <a href="exam-dates/{{ $date->id }}/unroll"
                                                   class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold py-2">Odzapsat</a>
                                            @elseif($subject->dates->where('enroll' , true)->count() === 0)
                                                <a href="exam-dates/{{ $date->id }}/enroll"
                                                   class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold py-2">Zapsat</a>
                                            @endif
                                        </td>
                                    </tr>
                                @endforeach
                            </table>
                        </div>
                    </div>
                </div>
            @endif
        @endforeach
    </div>

@endsection

@section('scripts')
    <script>
        $(document).ready(function () {
            $('.show').click(function () {
                let div = $('#div' + $(this).attr('target'));
                let id = $(this).attr('subject_id');
                if (div.is(':hidden')) {
                    div.show(400);
                    deleteNotifications(id);
                } else {
                    div.hide(400);
                }
            });

            function deleteNotifications(id) {
                $.ajax({
                    url: '{{ route('student.notifications.destroy') }}',
                    method: 'GET',
                    data: {
                        id:id,
                        type:2,
                    },
                    dataType: 'json',
                    success: function (data) {

                    }
                })
            }
        })
    </script>
@endsection


@section('breadcrumbs')
    {{ Breadcrumbs::render('student.exam-dates') }}
@endsection
