@extends('layouts.administration')

@section('title', 'Tvorba rozvrhu')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Tvorba rozvrhu</h2>
    <form action="/lessons/registration" method="POST">
        @csrf
        <div class="grid grid-flow-row grid-cols-2 md:grid-cols-4">
            <div class="col-span-2">
                <ul class="px-2 py-5">
                    <li class="pb-2"><span
                            class="font-semibold">Datum předzápisu:</span> {{ $setting->preregistration->isoFormat('LLL') . ' – ' . $setting->registration->isoFormat('LLL')}}
                    </li>
                    <li class="pb-2"><span
                            class="font-semibold">Datum zápisu:</span> {{ $setting->registration->isoFormat('LLL') . ' – ' . $setting->end_registration->isoFormat('LLL')}}
                    </li>
                </ul>
            </div>
            <div class="col-span-2 px-2 py-5">
                <button type="submit"
                        class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700">
                    Zapsat
                </button>
            </div>
        </div>


        <table class="w-full text-center border-collapse border border-black mt-5">
            <tr>
                <th class="py-5 px-15 md:px-0"></th>
                @for($i = 0; $i < 10; $i++)
                    <th class="py-5 px-5 md:px-0 whitespace-nowrap border border-black">
                        {{ $setting->start->addMinutes($i * 50)->isoFormat('H:mm') . '-' . $setting->start->addMinutes(($i + 1) * 45 + ($i * 5))->isoFormat('H:mm') }}
                    </th>
                @endfor
            </tr>


            @for($i = 0; $i < 5; $i++)
                @php
                    $size = 1;
                @endphp
                @if($lessons)
                    @php
                        $lessonsOfDay = $lessons->where('day', $i + 1);
                    @endphp
                    @for($j = 0; $j < 10; $j++)
                        @php
                            $count = $lessonsOfDay->where('start', $j + 1)->count();

                            for ($k = 0; $k < 4; $k++) {
                                $count += $lessons->where('day', $i + 1)->where('start', '=', $j - $k)->where('end', '>', $j + 1)->count();
                            }

                            if ($size < $count) $size = $count;
                            $length = 0;
                        @endphp
                    @endfor
                @endif

                @for($j = 0; $j < $size; $j++)
                    <tr class="border border-black h-24">
                        @if($j === 0)
                            <td class="py-2 border border-black" rowspan="{{ $size }}">
                                @switch($i)
                                    @case(0)
                                    Pondělí
                                    @break
                                    @case(1)
                                    Úterý
                                    @break
                                    @case(2)
                                    Středa
                                    @break
                                    @case(3)
                                    Čtvrtek
                                    @break
                                    @case(4)
                                    Pátek
                                    @break
                                @endswitch
                            </td>
                        @endif

                        @for($k = 0; $k < 10; $k++)
                            @if($lessons)
                                @php
                                    $lesson = $lessonsOfDay->where('start', $k + 1)->first();
                                    $key = $lessonsOfDay->where('start', $k + 1)->keys()->first();
                                @endphp
                                @else
                                @php
                                    $lesson = null;
                                    $length = null;
                                @endphp
                            @endif
                            @if($lesson && $length === 0)
                                @php
                                    $length = $lesson->end - $lesson->start - 1;
                                @endphp
                                <td class="py-1 border border-black relative {{ ($lesson->type === 1) ? 'bg-' . $lesson->color . '-500' : 'bg-' . $lesson->color . '-300' }}"
                                    colspan="{{ $lesson->end - $lesson->start }}">
                                    @if($now >= $setting->preregistration && $now <= $setting->end_registration)
                                        <div class="absolute top-1/2 left-1 transform -translate-y-1/2">
                                            <input type="checkbox"
                                                   class="checkbox-lesson form-checkbox border border-gray-400"
                                                   {{ ($lesson->preregistration === true) ? 'checked' : '' }}
                                                   {{ ($lesson->occupancy === $lesson->capacity && !isset($lesson->preregistration)) ? 'disabled' : '' }}
                                                   name="lessons[{{ $i . $k }}]"
                                                   value="{{ $lesson->id }}">
                                        </div>
                                    @endif

                                    <div class="pt-3 px-2">
                                        {{ $lesson->subject->shortname }}
                                        @if($lesson->type === 1)
                                            <i class="fas fa-chalkboard-teacher"></i>
                                        @elseif($lesson->type === 2)
                                            <i class="fas fa-user-edit"></i>
                                        @endif
                                    </div>
                                    <div class="pb-2 px-2">{{ $lesson->teacher->username }}</div>

                                    <div class="absolute top-0 right-1">
                                        <p>
                                            {{ $lesson->occupancy . '/' . $lesson->capacity }}
                                        </p>
                                    </div>
                                    <div class="absolute bottom-0 right-1">
                                        <p>
                                            {{ $lesson->room }}
                                        </p>
                                    </div>
                                </td>
                                @php
                                    $lessonsOfDay->forget($key);
                                @endphp
                            @elseif($length > 0)
                                @php
                                    --$length;
                                @endphp
                            @else
                                <td class="py-2 border border-black"></td>
                            @endif
                        @endfor
                    </tr>
                @endfor
            @endfor
        </table>
    </form>

    <script>
        $(document).ready(function () {

            $('.checkbox-lesson').change(function () {
                if ($(this).prop('checked')) {

                    $.ajaxSetup({headers: {'X-CSRF-TOKEN': '{{csrf_token()}}'}});

                    $.ajax({
                        url: '{{ url('/lessons/pre-registration') }}',
                        method: 'POST',
                        dataType: 'text',
                        data: {
                            id: $(this).val(),
                        }, success: function (response) {
                            location.reload();
                        }
                    })
                } else {

                    $.ajaxSetup({headers: {'X-CSRF-TOKEN': '{{csrf_token()}}'}});

                    $.ajax({
                        url: '{{ url('/lessons/pre-unregistration') }}',
                        method: 'POST',
                        dataType: 'text',
                        data: {
                            id: $(this).val(),
                        }, success: function (response) {
                            location.reload();
                        }
                    })
                }
            });
        });
    </script>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('student.lessons') }}
@endsection
