@extends('layouts.subject')

@section('title', 'Upravit úlohu')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Upravit úlohu</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form action="/subjects/{{ $subject->id }}/categories/{{ $category->id }}/questions/{{ $question->id }}"
              method="POST">
            @csrf
            @method('put')
            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Název</span>
                <input name="name" type="text"
                       class="@error('name') border-red-500 @enderror form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200"
                       value="{{ old('name', $question->name) }}">
                @error('name')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Zadání</span>
                <div class="mt-2">
                    <textarea class="form-control" id="summary-ckeditor" name="task">{!! old('task', $question->task) !!}</textarea>
                </div>
                @error('task')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            @switch($question->type)
                @case(1)
                @include('subjects.categories.questions.edit-type-1')
                @break
                @case(2)
                @include('subjects.categories.questions.edit-type-2')
                @break
                @case(3)
                @include('subjects.categories.questions.edit-type-3')
                @break
            @endswitch

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">Upravit</button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.categories.show.questions.edit', $subject, $category, $question) }}
@endsection

@section('scripts')
    <script>
        ClassicEditor
            .create( document.querySelector( '#summary-ckeditor' ) )
            .catch( error => {
                console.error( error );
            } );
    </script>
    <script>
        $(document).ready(function () {
            let editors = $('.answer');

            editors.each(function (editor) {
                ClassicEditor
                    .create( this )
                    .catch( error => {
                        console.error( error );
                    } );
            });

            let div = document.querySelector('#answer');

            let counter = {{ (isset($count) ? $count : '0') }};
            $("#addRightAnswer").click(function () {
                counter++;
                let input = '<div class="block my-2"><span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Odpověď ' + counter + '</span><input name="answer[' + counter + ']" type="text" class="@error("answer[' + counterRightAnswer + ']") border-red-500 @enderror form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200">@error("answer[' + counterRightAnswer + ']")<p class="text-red-500 text-xs italic mt-2">{{ $message }}</p>@enderror</div>';
                div.insertAdjacentHTML('beforeend', input)
            });

            $("#addAnswer").click(function () {
                if (counter < 6) {
                    counter++;
                    let input = '<div class="block my-2"><span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Odpověď ' + counter + '</span><div class="mt-2"><select name="grades[' + counter + ']" class="form-select block w-full my-2 border border-gray-200"> <option value="1">Špatná odpověď</option> <option value="2">Správná odpověď</option> </select> <textarea class="answer form-control" id="answer[' + counter + ']" name="answer[' + counter + ']"></textarea> </div>@error("answer[' + counterAnswer + ']")<p class="text-red-500 text-xs italic mt-2">{{ $message }}</p>@enderror</div>';
                    div.insertAdjacentHTML('beforeend', input)
                    let editors = document.querySelectorAll('.answer');
                    ClassicEditor
                        .create( editors[counter - 1] )
                        .catch( error => {
                            console.error( error );
                        } );
                }
            });
        });
    </script>
@endsection


