@extends('layouts.subject')

@section('title', 'Úlohy kategorie')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">{{ $category->name }}</h2>

    <button
        class="block text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold mt-5"
        id="openModal">Přidat novou úlohu
    </button>

    @if($category->questions->isNotEmpty())
        <form action="{{ $category->id }}/questions-delete"
              method="POST">
            @csrf
            @method('delete')
            <div class="overflow-x-auto">
                <table class="w-full text-center mt-5">
                    <tr>
                        <th class="py-5 px-5 md:px-0"></th>
                        <th class="py-5 px-5 md:px-0">Typ</th>
                        <th class="py-5 px-5 md:px-0">Název</th>
                        <th class="py-5 px-5 md:px-0">Datum vytvoření</th>
                        <th class="py-5 px-5 md:px-0">Datum poslední úpravy</th>
                        <th class="py-5 px-15 md:px-0"></th>
                        <th class="py-5 px-15 md:px-0"></th>
                    </tr>
                    @foreach($category->questions as $key => $question)
                        <tr class="border-b border-gray-400">
                            <td class="py-2">
                                <input type="checkbox" class="form-checkbox border border-gray-400"
                                       name="questions[{{ $key }}]"
                                       value="{{ $question->id }}">
                            </td>
                            <td class="py-2">
                                @if($question->type === 1)
                                    <i class="fas fa-list"></i>
                                @elseif($question->type === 2)
                                    <i class="fas fa-percentage"></i>
                                @elseif($question->type === 3)
                                    <i class="far fa-keyboard"></i>
                                @endif
                            </td>
                            <td class="py-2">{{ $question->name }}</td>
                            <td class="py-2">{{ $question->created_at->isoFormat('LLL') }}</td>
                            <td class="py-2">{{ $question->updated_at->isoFormat('LLL') }}</td>
                            <td class="py-2">
                                <a href="{{ $category->id }}/questions/{{ $question->id }}"
                                   class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold py-2">Náhled</a>
                            </td>
                            <td class="py-2">
                                <a href="{{ $category->id }}/questions/{{ $question->id }}/edit"
                                   class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold py-2">Upravit</a>
                            </td>
                        </tr>
                    @endforeach
                </table>
            </div>

            <button type="submit"
                    class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                Odstranit vybrané úlohy
            </button>
        </form>
    @else
        <p class="text-xl pl-5 py-2 text-red-600">Nebyly nalezeny žádné úlohy kategorie.</p>
    @endif
@endsection

@section('modal')
    <div id="modal"
         class="pt-1/12 hidden fixed left-0 right-0 top-0 w-full h-full overflow-hidden bg-black bg-opacity-40">
        <div id="modalContent" class="relative bg-white m-auto w-2/3 rounded pt-5 px-10">
            <div class="text-xl font-semibold uppercase tracking-wider">
                <h4>Přidání úlohy</h4>
                <span id="closeModal" class="right-0 top-0 absolute pt-5 px-10 cursor-pointer">&times;</span>
            </div>
            <div class="py-5">
                <form method="POST" action="{{ $category->id }}/questions/type">
                    @csrf
                    <div class="block">
                        <div class="mt-2">
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="1">
                                    <span class="ml-2"><i class="fas fa-list"></i> Výběr z možností</span>
                                </label>
                            </div>
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="2">
                                    <span class="ml-2"><i class="fas fa-percentage"></i> Pravda nepravda</span>
                                </label>
                            </div>
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="3">
                                    <span class="ml-2"><i class="far fa-keyboard"></i> Krátká tvořená odpověď</span>
                                </label>
                            </div>
                        </div>
                    </div>

                    <button type="submit"
                            class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                        Přidat
                    </button>
                </form>
            </div>
        </div>
    </div>

@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.categories.show', $subject, $category) }}
@endsection

@section('scripts')
    <script>
        $(document).ready(function () {

            var button = $('#openModal');
            var modal = $('#modal')
            var span = $('#closeModal')

            if (button != null) {
                button.click(function (e) {
                    modal.removeClass('hidden');
                });
            }

            if (span != null) {
                span.click(function (e) {
                    modal.addClass('hidden');
                });
            }

            modal.click(function (e) {
                if (!$(e.target).closest('#modalContent').length && !$(e.target).is('#modalContent')) {
                    modal.addClass('hidden');
                }
            })
        })
    </script>
@endsection
