@extends('layouts.subject')

@section('title', 'Upravit termín')

@section('content')

    <h2 class="text-3xl font-semibold uppercase tracking-wider">Upravit termín</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form class="w-full space-y-2 sm:space-y-4"
              action="/subjects/{{ $subject->id }}/exam-dates/{{ $examDate->id }}" method="POST">
            @csrf
            @method('put')

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum začátku</span>
                <input name="date_start" type="datetime-local"
                       value="{{ old('date_start', \Carbon\Carbon::parse($examDate->date_start)->format('Y-m-d\TH:i')) }}"
                       min="{{ \Carbon\Carbon::now()->format('Y-m-d\TH:i') }}"
                       class="date_start @error('date_start') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('date_start')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum konce</span>
                <input name="date_end" type="datetime-local"
                       value="{{ old('date_end', \Carbon\Carbon::parse($examDate->date_end)->format('Y-m-d\TH:i')) }}"
                       min="{{ \Carbon\Carbon::now()->format('Y-m-d\TH:i') }}"
                       class="date_end @error('date_end') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('date_end')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Typ</span>
                <select name="type"
                        class="@error('type') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('type', $examDate->type) == 1) ? 'selected' : '' }}>Zápočtový termín</option>
                    <option value="2" {{ (old('type', $examDate->type) == 2) ? 'selected' : '' }}>Zkouškový termín</option>
                </select>
                @error('type')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Typ</span>
                <select name="form"
                        class="@error('form') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('form', $examDate->form) == 1) ? 'selected' : '' }}>Prezenční</option>
                    <option value="2" {{ (old('form', $examDate->form) == 2) ? 'selected' : '' }}>Online</option>
                </select>
                @error('form')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Místnost</span>
                <input name="room" type="text"
                       class="@error('room') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{ old('room', $examDate->room) }}">
                @error('room')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Kapacita</span>
                <input name="capacity" type="number" min="0"
                       class="@error('capacity') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{ old('capacity', $examDate->capacity) }}">
                @error('capacity')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                Upravit
            </button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.exam-dates.edit', $subject, $examDate) }}
@endsection
