@extends('layouts.subject')

@section('title', 'Upravit hodinu')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Upravit hodinu</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form class="w-full space-y-2 sm:space-y-4" action="/subjects/{{ $subject->id }}/lessons/{{ $lesson->id }}" method="POST">
            @csrf
            @method('put')

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Den</span>
                <select name="day"
                        class="@error('day') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('day', $lesson->day) == 1) ? 'selected' : ''}}>Pondělí</option>
                    <option value="2" {{ (old('day', $lesson->day) == 2) ? 'selected' : ''}}>Úterý</option>
                    <option value="3" {{ (old('day', $lesson->day) == 3) ? 'selected' : ''}}>Středa</option>
                    <option value="4" {{ (old('day', $lesson->day) == 4) ? 'selected' : ''}}>Čtvrtek</option>
                    <option value="5" {{ (old('day', $lesson->day) == 5) ? 'selected' : ''}}>Pátek</option>
                </select>
                @error('day')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Začátek</span>
                <select name="start"
                        class="@error('start') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    @for($i = 0; $i < 10; $i++)
                        <option
                            value="{{ $i + 1 }}" {{ (old('start', $lesson->start) == $i + 1) ? 'selected' : ''}}>{{ $setting->start->addMinutes($i * 50)->isoFormat('H:mm') }}</option>
                    @endfor
                </select>
                @error('start')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Délka</span>
                <select name="length"
                        class="@error('length') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('length', $lesson->end - $lesson->start) == 1) ? 'selected' : ''}}>1 hodina</option>
                    <option value="2" {{ (old('length', $lesson->end - $lesson->start) == 2) ? 'selected' : ''}}>2 hodiny</option>
                    <option value="3" {{ (old('length', $lesson->end - $lesson->start) == 3) ? 'selected' : ''}}>3 hodiny</option>
                    <option value="4" {{ (old('length', $lesson->end - $lesson->start) == 4) ? 'selected' : ''}}>4 hodiny</option>
                </select>
                @error('length')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Typ</span>
                <select name="type"
                        class="@error('type') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('type', $lesson->type) == 1) ? 'selected' : ''}}>Přednáška</option>
                    <option value="2" {{ (old('type', $lesson->type) == 2) ? 'selected' : ''}}>Cvičení</option>
                </select>
                @error('type')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Vyučující</span>
                <select name="user_id"
                        class="@error('user_id') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    @foreach($subject->teachers as $teacher)
                        <option
                            value="{{ $teacher->id }}" {{ (old('user_id', $lesson->teacher_id) == $teacher->id) ? 'selected' : ''}}>{{ $teacher->lastname }} {{ $teacher->firstname }}</option>
                    @endforeach
                </select>
                @error('user_id')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Místnost</span>
                <input name="room" type="text"
                       class="@error('room') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{ old('room', $lesson->room) }}">
                @error('room')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Kapacita</span>
                <input name="capacity" type="text"
                       class="@error('capacity') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200"
                       value="{{ old('capacity', $lesson->capacity) }}">
                @error('capacity')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">Upravit</button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.lessons.edit', $subject, $lesson) }}
@endsection
