@extends('layouts.subject')

@section('title', 'Přidat soubor')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Přidat soubor</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form action="/subjects/{{ $subject->id }}/menus/{{ $menu->id }}/files" method="POST"
              enctype="multipart/form-data">
            @csrf
            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Název</span>
                <input name="name" type="text" value="{{ old('name') }}"
                       class="@error('name') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('name')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Popis</span>
                <textarea name="description"
                          class="@error('description') border-red-500 @enderror form-textarea mt-2 block w-full border border-gray-200"
                          rows="3">{{ old('description') }}</textarea>
                @error('description')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Zobrazení</span>
                <select name="visible" id="select"
                        class="@error('visible') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('visible') == 1) ? 'selected' : '' }}>Zobrazit</option>
                    <option value="2" {{ (old('visible') == 2) ? 'selected' : '' }}>Skrýt</option>
                </select>
                @error('visible')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Soubor</span>
                <div
                    class="@error('file') border-red-500 @enderror mt-2 relative border-dotted h-48 rounded border-dashed border-2 border-gray-400 bg-white flex justify-center items-center">
                    <div class="absolute">
                        <div class="flex flex-col items-center"><i
                                class="fa fa-folder-open fa-4x text-black"></i>
                            <span id="label"
                                  class="block text-gray-400 font-normal">Přesuňte soubor nebo vyberte soubor</span>
                        </div>
                    </div>
                    <input type="file" class="h-full w-full opacity-0" name="file">
                </div>

                @error('file')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">Přidat</button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.menus.files.create', $subject, $menu) }}
@endsection

@section('scripts')
    <script>
        $(document).ready(function () {
            var inputFile = $('input[type=file]');
            inputFile.change(function (e) {
                $('#label').text(e.target.files[0].name);
            })
        })
    </script>
@endsection
