@extends('layouts.subject')

@section('title', $menu->name)

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">{{ $menu->name }}</h2>

    <div class="relative pb-10">
        <div
            class="ck-content relative text-justify leading-5 px-2 py-2 {{ (session('edit') === true && (Auth::user()->authorization === 1 || Auth::user()->authorization === 2)) ? 'mb-10' : 'mb-5' }}">
            {!! $contents[0]->text !!}
            @if(session('edit') === true && (Auth::user()->authorization === 1 || Auth::user()->authorization === 2))
                <a href="{{ $menu->id }}/contents/{{ $contents[0]->id }}/edit"
                   class="absolute right-0 bottom-0.5 text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold p-2">Upravit</a>
            @endif
        </div>

        @if($contents->count() > 1)
            <ul class="sortable-content">
                @foreach($contents as $key => $content)
                    <li data-index="{{ $content->id }}">
                        @if($content->file !== null)
                            @include('subjects.menus.files.card')
                        @elseif($content->test !== null)
                            @include('subjects.menus.tests.card')
                        @elseif($content->menu !== null)
                            @include('subjects.menus.card')
                        @endif
                    </li>
                @endforeach
            </ul>
        @endif

        @if(session('edit') === true && (Auth::user()->authorization === 1 || Auth::user()->authorization === 2))
            <div class="relative">
                <button
                    class="absolute right-0 text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold p-2"
                    id="openModal">Přidat činnost
                </button>
            </div>
        @endif
    </div>
@endsection

@section('modal')
    <div id="modal"
         class="pt-1/12 hidden fixed left-0 right-0 top-0 w-full h-full overflow-hidden bg-black bg-opacity-40">
        <div id="modalContent" class="relative bg-white m-auto w-2/3 rounded pt-5 px-10">
            <div class="text-xl font-semibold uppercase tracking-wider">
                <h4>Přidání činnosti</h4>
                <span id="closeModal" class="right-0 top-0 absolute pt-5 px-10 cursor-pointer">&times;</span>
            </div>
            <div class="py-5">
                <form method="POST" action="{{ $menu->id }}/activity">
                    @csrf
                    <div class="block">
                        <div class="mt-2">
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="1">
                                    <span class="mx-2"><i class="far fa-file mr-1"></i> Soubor</span>
                                </label>
                            </div>
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="2">
                                    <span class="mx-2"><i class="fas fa-spell-check mr-1"></i> Test</span>
                                </label>
                            </div>
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="3">
                                    <span class="mx-2"><i class="fas fa-book mr-1"></i> Domácí úkol</span>
                                </label>
                            </div>
                            <div>
                                <label class="inline-flex items-center my-2">
                                    <input type="radio" class="form-radio border border-gray-400" name="radio"
                                           value="4">
                                    <span class="mx-2"><i class="far fa-folder-open mr-1"></i> Složka</span>
                                </label>
                            </div>
                        </div>
                    </div>

                    <button type="submit"
                            class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                        Přidat
                    </button>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.menus', $subject, $menu) }}
@endsection

@section('scripts')
    <script>
        $(document).ready(function () {

            var button = $('#openModal');
            var modal = $('#modal')
            var span = $('#closeModal')

            if (button != null) {
                button.click(function (e) {
                    modal.removeClass('hidden');
                });
            }

            if (span != null) {
                span.click(function (e) {
                    modal.addClass('hidden');
                });
            }

            modal.click(function (e) {
                if (!$(e.target).closest('#modalContent').length && !$(e.target).is('#modalContent')) {
                    modal.addClass('hidden');
                }
            })
        })
    </script>
@append
