@extends('layouts.subject')

@section('title', 'Upravit klasifikaci')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Upravit klasifikaci</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form class="w-full space-y-2 sm:space-y-4" action="/subjects/{{ $subject->id }}/students/{{ $user->id }}/attempts/{{ $attempt->id }}/update" method="POST">
            @csrf
            @method('PUT')

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Název:</span>
                <input name="name" type="text" value="{{ old('name', $attempt->name) }}" {{ ($attempt->test_id !== null) ? 'disabled' : '' }}
                       class="@error('name') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('name')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Body:</span>
                <input name="points" type="number" value="{{ old('points', $attempt->points) }}" {{ ($attempt->test_id !== null) ? 'disabled' : '' }}
                    min="0"
                       class="@error('points') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('points')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Maximální počet bodů:</span>
                <input name="max_points" type="number" value="{{ old('max_points', $attempt->max_points) }}" {{ ($attempt->test_id !== null) ? 'disabled' : '' }}
                min="0"
                       class="@error('max_points') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('max_points')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Poznámka:</span>
                <textarea name="text"
                          class="@error('text') border-red-500 @enderror form-textarea mt-2 block w-full border border-gray-200"
                          rows="3">{{ old('text', $attempt->text) }}</textarea>
                @error('text')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                Upravit
            </button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.students.attempts.edit', $subject, \App\Models\User::find($attempt->user_id), $attempt) }}
@endsection
