@extends('layouts.subject')

@section('title', 'Přidat test')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Přidat test</h2>

    <div class="w-full md:w-2/3 mx-auto px-2 py-5">
        <form class="w-full space-y-2 sm:space-y-4" action="/subjects/{{ $subject->id }}/menus/{{ $menu->id }}/tests" method="POST">
            @csrf
            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Název</span>
                <input name="name" type="text" value="{{ old('name') }}"
                       class="@error('name') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('name')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Popis</span>
                <textarea name="description"
                          class="@error('description') border-red-500 @enderror form-textarea mt-2 block w-full border border-gray-200"
                          rows="3">{{ old('description') }}</textarea>
                @error('description')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Typ</span>
                <select name="type" id="select"
                        class="@error('type') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ old('type') === '1' ? 'selected' : '' }}>Procvičovací test</option>
                    <option value="2" {{ old('type') === '2' ? 'selected' : '' }}>Zápočtový test</option>
                    <option value="3" {{ old('type') === '3' ? 'selected' : '' }}>Zkouškový test</option>
                </select>
                @error('type')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Řazení otázek</span>
                <select name="random"
                        class="@error('random') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ old('random') == 1 ? 'selected' : '' }}>Postupně</option>
                    <option value="2" {{ old('random') == 2 ? 'selected' : '' }}>Náhodně</option>
                </select>
                @error('random')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2 hidden" id="date_start">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum začátku</span>
                <input name="date_start" type="datetime-local"
                       value="{{ old('date_start', \Carbon\Carbon::now()->format('Y-m-d\TH:i')) }}"
                       min="{{ \Carbon\Carbon::now()->format('Y-m-d\TH:i') }}"
                       class="date_start @error('date_start') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('date_start')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2 hidden" id="date_end">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Datum konce</span>
                <input name="date_end" type="datetime-local"
                       value="{{ old('date_end', \Carbon\Carbon::now()->format('Y-m-d\TH:i')) }}"
                       min="{{ \Carbon\Carbon::now()->format('Y-m-d\TH:i') }}"
                       class="date_end @error('date_end') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('date_end')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Časové omezení</span>
                <div class="flex mt-1" id="time">
                    <label class="flex items-center">
                        <input type="checkbox" value="time" name="timeCheck" id="timeCheck"
                               class="form-checkbox border border-gray-200" {{ old('timeCheck') == 'time' ? 'checked' : '' }}>
                        <span class="ml-2">Povolit</span>
                    </label>
                </div>
                <div class="flex flex-row">
                    <input name="time" type="number" disabled value="{{ old('time') }}"
                           class="time @error('time') border-red-500 @enderror form-input block w-10/12 mt-2 border border-gray-200 rounded-r-none disabled:bg-cool-gray-600 mr-0.5">
                    <select name="units" disabled
                            class="time @error('time') border-red-500 @enderror form-select block w-1/6 mt-2 border border-gray-200 rounded-l-none disabled:bg-cool-gray-600">
                        <option value="1" {{ old('units') == 1 ? 'selected' : '' }}>Sekund</option>
                        <option value="60" {{ old('units') == 60 || old('time') === null ? 'selected' : '' }}>Minut</option>
                        <option value="360" {{ old('units') == 360 ? 'selected' : '' }}>Hodin</option>
                    </select>
                </div>
                @error('time')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2 hidden" id="password">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Heslo</span>
                <input name="password" type="text" value="{{ old('password') }}"
                       class="@error('password') border-red-500 @enderror form-input block w-full mt-2 border border-gray-200">
                @error('password')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <label class="block my-2">
                <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Zobrazení</span>
                <select name="visible" id="select"
                        class="@error('visible') border-red-500 @enderror form-select block w-full mt-2 border border-gray-200">
                    <option value="1" {{ (old('visible') == 1) ? 'selected' : '' }}>Zobrazit</option>
                    <option value="2" {{ (old('visible') == 2) ? 'selected' : '' }}>Skrýt</option>
                </select>
                @error('visible')
                <p class="text-red-500 text-xs italic mt-2">
                    {{ $message }}
                </p>
                @enderror
            </label>

            <button type="submit" class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">Přidat</button>
        </form>
    </div>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.menus.tests.create', $subject, $menu) }}
@endsection

@section('scripts')
    <script src="{{ asset('js/test-form.js') }}" defer></script>
@endsection
