@extends('layouts.subject')

@section('title', 'Úlohy testu ' . $test->name)

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Úlohy testu</h2>

    @if(count($test->attempts) > 0)
        <p class="text-justify leading-5 px-2 py-5">Test má {{ count($test->attempts) }} započatých pokusů. Už nemůžete
            přidat, odstranit úlohy ani změnit počet bodů</p>
    @else
        <a href="questions-add"
           class="block text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold pt-10">Přidat
            úlohu</a>
    @endif

    @if($test->questions->isNotEmpty())
        <form action=""
              method="POST">
            @csrf
            @method('delete')
            <table class="w-full text-center px-2 py-5">
                <tr>
                    <th class="py-5 px-5 md:px-0"></th>
                    <th class="py-5 px-5 md:px-0">Typ</th>
                    <th class="py-5 px-5 md:px-0">Název</th>
                    <th class="py-5 px-5 md:px-0">Body</th>
                    <th class="py-5 px-15 md:px-0"></th>
                    @if(!$test->attempts)
                        <th class="py-5 px-15 md:px-0"></th>
                    @endif
                </tr>
                <tbody class="sortable-question">
                @foreach($test->questions as $key => $question)
                    <tr data-index="{{ $question->pivot->id }}" class="border-b border-gray-400">
                        <td class="py-2">
                            <input type="checkbox" class="form-checkbox border border-gray-400"
                                   name="questions[{{ $key }}]"
                                   value="{{ $question->id }}">
                        </td>
                        <td class="py-2">
                            @if($question->type === 1)
                                <i class="fas fa-list"></i>
                            @elseif($question->type === 2)
                                <i class="fas fa-percentage"></i>
                            @elseif($question->type === 3)
                                <i class="far fa-keyboard"></i>
                            @endif
                        </td>
                        <td class="py-2">{{ $question->name }}</td>
                        <td class="py-2">
                            <p class="text" id="{{ $question->pivot->id }}">{{ $question->pivot->point }}</p>
                        </td>
                        <td class="py-2">
                            <a href="/subjects/{{ $subject->id }}/categories/{{ $subject->category->id }}/questions/{{ $question->id }}"
                               class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold py-2">Náhled</a>
                        </td>
                        @if(!$test->attempts)
                            <td class="py-2">
                                <form action="questions/{{ $question->pivot->id }}" method="POST">
                                    @csrf
                                    @method('delete')
                                    <button
                                        class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold py-2">
                                        Odstranit
                                    </button>
                                </form>
                            </td>
                        @endif
                    </tr>
                @endforeach
                </tbody>
            </table>
            <button type="submit"
                    class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                Odstranit vybrané úlohy
            </button>
        </form>
    @else
        <p class="text-xl pl-5 py-2 text-red-600">Nebyly nalezeny žádné úlohy testu.</p>
    @endif

@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.menus.tests.questions', $subject, $menu, $test) }}
@endsection

@if(count($test->attempts) === 0)
@section('scripts')
    <script>
        $(document).on("focusout", ".point", function () {
            var input = $('.point');
            var point = input.val();
            var id = input.attr('id');

            $.ajaxSetup({headers: {'X-CSRF-TOKEN': '{{csrf_token()}}'}});

            $.ajax({
                url: '{{ url('/questions/update-point') }}',
                method: 'POST',
                dataType: 'text',
                data: {
                    updatedPoint: 1,
                    id: id,
                    point: point,
                }, success: function (response) {
                    var text = $("<p>", {
                        class: 'text',
                        id: input.attr('id'),
                        text: input.val(),
                    }, "</p>");
                    input.replaceWith(text);
                }
            })
        });

        $(document).on("click", ".text", function () {
            if (!$(".point")[0]) {
                var input = $("<input>", {
                    id: $(this).attr('id'),
                    val: $(this).text(),
                    type: "number",
                    name: "point",
                    class: "point form-input block w-1/6 focus:shadow-outline-gray mx-auto border border-gray-200",
                });
                $(this).replaceWith(input);
                input.select();
            }
        });
    </script>
@endsection
@endif
