@extends('layouts.appWoMenu')

@section('title', $test->name)

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">{{ $test->name }}</h2>

    <p class="text-justify leading-5 px-2 py-5">{!! $test->description !!}</p>
    <div class="px-2 py-5">
        <ul>
            @switch($test->type)
                @case(1)
                <li class="pb-2"><span class="font-semibold">Typ:</span> Procvičovací test</li>
                @break
                @case(2)
                <li class="pb-2"><span class="font-semibold">Typ:</span> Zápočtový test</li>
                @break
                @case(3)
                <li class="pb-2"><span class="font-semibold">Typ:</span> Zkouškový test</li>
                @break
            @endswitch
            <li class="pb-2"><span class="font-semibold">Celkový počet bodů:</span> {{ $test->points }}</li>
        </ul>
    </div>

    @if($test->questions->isNotEmpty())

        @if($test->time !== null)
            <div class="relative pt-1 sticky top-0">
                <div class="flex mb-2 items-center justify-between">
                    <div>
                        <span
                            class="text-xs font-semibold inline-block py-1 px-2 uppercase rounded-full bg-black text-white">Časový limit:</span>
                    </div>
                    <div class="text-right">
                        <span id="count" class="text-xs font-semibold inline-block text-black">0 s</span>
                    </div>
                </div>
                <div id="bgTimer" class="overflow-hidden h-2 mb-4 text-xs flex rounded bg-green-300">
                    <div id="timer"
                         class="shadow-none flex flex-col text-center whitespace-nowrap text-white justify-center bg-green-600"></div>
                </div>
            </div>
        @endif

        <div class="w-full mp:w-2/3 mx-auto">
            <form id="examForm" action="/subjects/{{ $subject->id }}/menus/{{ $menu->id }}/tests/{{ $test->id }}"
                  method="POST">
                @csrf

                @php
                    if ($test->random === 2){
                        $questions = $test->questionsRandom;
                    } else {
                        $questions = $test->questions;
                    }
                    info($questions)
                @endphp
                @foreach($questions as $key => $question)
                    @switch($question->type)
                        @case(1)
                        @include('subjects.menus.tests.show-type-1')
                        @break
                        @case(2)
                        @include('subjects.menus.tests.show-type-2')
                        @break
                        @case(3)
                        @include('subjects.menus.tests.show-type-3')
                        @break
                    @endswitch
                @endforeach

                <button type="submit"
                        class="w-full font-bold whitespace-no-wrap p-2 rounded text-lg text-white bg-black hover:bg-gray-700 mb-3">
                    Odeslat
                </button>
            </form>
        </div>

    @else
        <p class="text-xl pl-5 py-2 text-red-600">Nebyly nalezeny žádné úlohy testu.</p>
    @endif
@endsection

@if($test->time !== null)
@section('scripts')
    <script defer>
        let countLimit = {{ $test->time }};
        let count = {{ $test->time }};
        let time = 0;
        let step = 100 / count;
        let width = 0;
        fromSecondToHMS(count);

        $(function () {
            setInterval(function () {
                updateTime(time);
            }, 1000);
        });

        function updateTime() {
            if (time <= countLimit) {
                width += step;
                $('#timer').css('width', width + '%');
                if (width >= 75) {
                    $('#bgTimer').removeClass('bg-green-300');
                    $('#bgTimer').addClass('bg-red-300');
                    $('#timer').removeClass('bg-green-600');
                    $('#timer').addClass('bg-red-600');
                }
                count--;

                fromSecondToHMS(count);
                time++
            }
            if (count == 0) {
                $("#examForm").submit();
            }
        }

        function fromSecondToHMS(count) {
            let string = '';
            let hour = Math.floor(count / 3600);
            if (hour > 0) string += hour + " h "
            let min = Math.floor((count % 3600) / 60);
            if (min > 0) string += min + " m "
            let sec = count % 60;
            string += sec + " s"
            document.querySelector('#count').innerHTML = string;
        }
    </script>
@endsection
@endif


