@extends('layouts.subject')

@section('title', 'Studenti předmětu')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider">Studenti předmětu</h2>

    <input type="text" name="search" id="search"
           class="form-input block w-full focus:shadow-outline-gray mt-2 border border-gray-200 mt-10">

    <label class="block my-2">
        <span class="block text-gray-700 text-sm font-bold mb-1 md:mb-2">Cvičení:</span>
        <select name="practice" id="select"
                class="form-select block w-full mt-2 border border-gray-200">
            <option value="0">Všechny cvičení</option>
            @foreach($subject->practice as $lesson)
                <option value="{{ $lesson->id }}">Cvičení
                    od: {{ $setting->start->addMinutes(($lesson->start - 1) * 50)->isoFormat('H:mm') }}
                    do: {{ $setting->start->addMinutes((($lesson->end - 1) * 50) - 5)->isoFormat('H:mm') }}</option>
            @endforeach
        </select>
    </label>

    <div class="list">
        @include('subjects.students.list', ['students' => $students])
    </div>

    <input type="hidden" name="hidden_page" id="hidden_page" value="1"/>
@endsection

@section('breadcrumbs')
    {{ Breadcrumbs::render('subjects.students', $subject) }}
@endsection

@section('scripts')
    <script>
        let url = "{{ "/subjects/" . $subject->id . "/students/search" }}";
    </script>
    <script src="{{ asset('js/live-search.js') }}"></script>
    <script defer>
        $(document).ready(function () {

            $(document).on("click", '[class^="show"]', function () {
                let div = $('#div' + $(this).attr('target'));
                if (div.is(':hidden')) {
                    div.show(400);
                } else {
                    div.hide(400);
                }
            });

            $(document).on("click", '[class^="grade"]', function () {
                let value = $(this).text();
                let target = $(this).attr('target');
                let type = $(this).attr('type');

                let select = $("<select>", {
                    id: 'select',
                    type: type,
                    target: target,
                    name: "credit",
                    class: "form-select border border-gray-200",
                });
                let text = ["", "A", "B", "C", "D", "E", "F"];
                value = $.inArray(value, text);
                $.each(text, function (i, grade) {
                    if (i === value) {
                        select.append($('<option>', {
                            value: i,
                            text: grade,
                            selected: true,
                        }))
                    } else {
                        select.append($('<option>', {
                            value: i,
                            text: grade,
                        }))
                    }
                })

                $(this).replaceWith(select);
                select.focus();
            });

            $(document).on("focusout", '[id="select"]', function () {
                let grade = $(this).val();
                let type = $(this).attr('type');
                let target = $(this).attr('target');

                let url = ''
                if (type.includes('exam')) {
                    url = '{{ url('/classification/update-exam') }}';
                }
                if (type.includes('credit')) {
                    url = '{{ url('/classification/update-credit') }}';
                }

                $.ajaxSetup({headers: {'X-CSRF-TOKEN': '{{csrf_token()}}'}});

                $.ajax({
                    url: url,
                    method: 'POST',
                    data: {
                        user_id: target,
                        subject_id: {{ $subject->id }},
                        grade: grade,
                    }, success: function (result) {
                        let span = ""
                        if (result === 'true') {
                            let text = ["?", "A", "B", "C", "D", "E", "F"];
                            span = $("<span>", {
                                target: target,
                                class: 'grade',
                                type: type,
                                text: text[grade],
                            }, "</span>");
                        }

                        if (result === 'false') {
                            let text = "Nesplněný zápočet";
                            span = $("<span>", {
                                target: target,
                                class: 'grade',
                                type: type,
                                text: text,
                            }, "</span>");
                        }

                        $('#select').replaceWith(span);
                    }
                })
            });
        })
    </script>
@endsection
