@extends('layouts.administration')

@section('title', 'Harmonogram ' . $year . '. ročníku')

@section('content')
    <h2 class="text-3xl font-semibold uppercase tracking-wider mb-4">Harmonogram {{ $year }}. ročníku</h2>

    @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
        <a href="schedules/create"
           class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">Přidat
            novou položku do harmonogramu</a>
    @endif

    <div class="overflow-x-auto">
        <table class="w-full text-left md:text-center mt-2 table-auto">
            <tr>
                <th class="py-2 px-5 md:px-0">Datum</th>
                <th class="py-2 px-5 md:px-0">Název</th>
                @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                    <th class="py-2 px-15 md:px-0"></th>
                @endif
            </tr>
            <tr class="border-b border-gray-400">
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $setting->first_semester_start->isoFormat('LL') }}</td>
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">Začátek zimního semestru</td>
                @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap"></td>
                @endif
            </tr>
            @foreach($schedules_first as $schedule)
                <tr class="border-b border-gray-400">
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $schedule->date_start->isoFormat('LL') . (($schedule->date_end === null) ? '' : ' – ' . $schedule->date_end->isoFormat('LL')) }}</td>
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $schedule->text }}</td>
                    @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">
                            <a href="schedules/{{ $schedule->id }}/edit"
                               class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">Upravit</a>
                            <form action="schedules/{{ $schedule->id }}" method="POST">
                                @csrf
                                @method('delete')
                                <button
                                    class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">
                                    Odstranit
                                </button>
                            </form>
                        </td>
                    @endif
                </tr>
            @endforeach
            <tr class="border-b border-gray-400">
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $setting->first_semester_end->isoFormat('LL') }}</td>
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">Konec zimního semestru</td>
                @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap"></td>
                @endif
            </tr>
        </table>
    </div>

    <div class="overflow-x-auto">
        <table class="w-full text-left md:text-center mt-2 table-auto">
            <tr>
                <th class="py-2 px-5 md:px-0">Datum</th>
                <th class="py-2 px-5 md:px-0">Název</th>
                @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                    <th class="py-2 px-15 md:px-0"></th>
                @endif
            </tr>
            <tr class="border-b border-gray-400">
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $setting->second_semester_start->isoFormat('LL') }}</td>
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">Začátek letního semestru</td>
                @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap"></td>
                @endif
            </tr>
            @foreach($schedules_second as $schedule)
                <tr class="border-b border-gray-400">
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $schedule->date_start->isoFormat('LL') . (($schedule->date_end === null) ? '' : ' – ' . $schedule->date_end->isoFormat('LL')) }}</td>
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $schedule->text }}</td>
                    @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                        <td class="py-2 px-5 md:px-0 whitespace-nowrap">
                            <a href="schedules/{{ $schedule->id }}/edit"
                               class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">Upravit</a>
                            <form action="schedules/{{ $schedule->id }}" method="POST">
                                @csrf
                                @method('delete')
                                <button
                                    class="text-gray-600 hover:text-gray-900 whitespace-no-wrap no-underline hover:underline font-bold">
                                    Odstranit
                                </button>
                            </form>
                        </td>
                    @endif
                </tr>
            @endforeach
            <tr class="border-b border-gray-400">
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">{{ $setting->second_semester_end->isoFormat('LL') }}</td>
                <td class="py-2 px-5 md:px-0 whitespace-nowrap">Konec letního semestru</td>
                @if(Auth::user()->authorization === 1 || Auth::user()->authorization === 2)
                    <td class="py-2 px-5 md:px-0 whitespace-nowrap"></td>
                @endif
            </tr>
        </table>
    </div>
@endsection

@if(\Illuminate\Support\Facades\Auth::user()->authorization === 1)
@section('breadcrumbs')
    {{ Breadcrumbs::render('admin.years.schedules', $year) }}
@endsection
@else
@section('breadcrumbs')
    {{ Breadcrumbs::render('student.years.schedules', $year) }}
@endsection
@endif
