<?php

use App\Http\Controllers\PagesController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::group([
    'middleware' => 'auth',
], function () {
    Route::get('/home', [PagesController::class, 'home'])->name('home');
    Route::get('/admin', [PagesController::class, 'administration'])->name('admin');

    Route::group([
        'prefix' => 'admin',
        'namespace' => 'Admin',
        'middleware' => 'admin',
        'as' => 'admin.',
    ], function () {
        Route::get('/admins/search', 'AdminsController@search')->name('admins.search');
        Route::resource('/admins', 'AdminsController', [
            'names' => [
                'index' => 'admins.index',
                'create' => 'admins.create',
                'store' => 'admins.store',
                'edit' => 'admins.edit',
                'update' => 'admins.update',
                'show' => 'admins.show',
                'destroy' => 'admins.destroy',
            ]
        ]);

        Route::get('/teachers/search', 'TeachersController@search')->name('teachers.search');
        Route::resource('/teachers', 'TeachersController', [
            'names' => [
                'index' => 'teachers.index',
                'create' => 'teachers.create',
                'store' => 'teachers.store',
                'edit' => 'teachers.edit',
                'update' => 'teachers.update',
                'show' => 'teachers.show',
                'destroy' => 'teachers.destroy',
            ]
        ]);

        Route::get('/students/search', 'StudentsController@search')->name('students.search');
        Route::resource('/students', 'StudentsController', [
            'names' => [
                'index' => 'students.index',
                'create' => 'students.create',
                'store' => 'students.store',
                'edit' => 'students.edit',
                'update' => 'students.update',
                'show' => 'students.show',
                'destroy' => 'students.destroy',
            ]
        ]);

        Route::get('/fields/{id_field}/subjects', 'FieldsController@subjects')->name('fields.subjects');
        Route::post('/fields/{id_field}/subjects', 'FieldsController@addSubject');
        Route::delete('/fields/{id_field}/subjects', 'FieldsController@deleteSubject');
        Route::get('/fields/search', 'FieldsController@search')->name('fields.search');
        Route::resource('/fields', 'FieldsController', [
            'names' => [
                'index' => 'fields.index',
                'create' => 'fields.create',
                'store' => 'fields.store',
                'edit' => 'fields.edit',
                'update' => 'fields.update',
                'show' => 'fields.show',
                'destroy' => 'fields.destroy',
            ]
        ]);

        Route::get('/subjects/{id_subject}/teachers', 'SubjectsController@teachers')->name('subjects.teachers');
        Route::post('/subjects/{id_subject}/teachers', 'SubjectsController@addTeacher');
        Route::delete('/subjects/{id_subject}/teachers', 'SubjectsController@deleteTeacher');
        Route::get('/subjects/search', 'SubjectsController@search')->name('subjects.search');
        Route::resource('/subjects', 'SubjectsController', [
            'names' => [
                'index' => 'subjects.index',
                'create' => 'subjects.create',
                'store' => 'subjects.store',
                'edit' => 'subjects.edit',
                'update' => 'subjects.update',
                'show' => 'subjects.show',
                'destroy' => 'subjects.destroy',
            ]
        ]);

        Route::get('/settings/edit', 'SettingsController@edit')->name('settings.edit');
        Route::put('/settings/{id}', 'SettingsController@update');

        Route::resource('/years', 'YearsController', [
            'only' => ['index'],
            'names' => [
                'index' => 'years'
            ]
        ]);
        Route::resource('/years/{year}/schedules', 'SchedulesController', [
            'names' => [
                'index' => 'years.schedules',
                'create' => 'years.schedules.create',
                'store' => 'years.schedules.store',
                'edit' => 'years.schedules.edit',
                'update' => 'years.schedules.update',
            ]
        ]);
    });

    Route::group([
        'namespace' => 'Teacher',
        'middleware' => 'teacher',
        'as' => 'teacher.'
    ], function () {

        Route::group([
            'as' => 'subjects.',
            'prefix' => 'subjects/{id_subject}',
        ], function () {

            Route::post('/students/{id_user}/attempts/store', 'AttemptsController@store');
            Route::put('/students/{id_user}/attempts/{id_attempt}/update', 'AttemptsController@update');
            Route::resource('/students/{id_user}/attempts', 'AttemptsController', [
                'names' => [
                    'create' => 'students.attempts.create',
                    'edit' => 'students.attempts.edit',
                    'destroy' => 'students.attempts.destroy',
                ],
            ]);

            Route::post('/menus/{id_menu}/activity', 'MenusController@activity');
            Route::get('/menus/{id_menu}/menus/create', 'MenusController@createContentMenu')->name('menus.menus.create');
            Route::post('/menus/{id_menu}/menus', 'MenusController@storeContentMenu');
            Route::get('/menus/{id_menu}/menus/{id}/edit', 'MenusController@editContentMenu')->name('menus.menus.edit');
            Route::put('/menus/{id_menu}/menus/{id}', 'MenusController@updateContentMenu');
            Route::resource('/menus', 'MenusController', [
                'only' => ['create', 'store', 'destroy'],
                'names' => [
                    'create' => 'menus.create',
                    'store' => 'menus.store',
                    'destroy' => 'menus.destroy',
                ],
            ]);

            Route::get('/students/search', 'SubjectsController@search');
            Route::get('/students', 'SubjectsController@students')->name('students');
            Route::get('/edit', 'SubjectsController@edit')->name('sylabus.edit');
            Route::put('', 'SubjectsController@update');

            Route::resource('/categories', 'CategoriesController', [
                'names' => [
                    'index' => 'categories',
                    'show' => 'categories.show',
                    'create' => 'categories.create',
                    'store' => 'categories.store',
                    'edit' => 'categories.edit',
                    'update' => 'categories.update',
                ]
            ]);

            Route::resource('/exam-dates', 'ExamDatesController', [
                'names' => [
                    'index' => 'exam-dates',
                    'create' => 'exam-dates.create',
                    'store' => 'exam-dates.store',
                    'edit' => 'exam-dates.edit',
                    'update' => 'exam-dates.update',
                ]
            ]);

            Route::resource('/lessons', 'LessonsController', [
                'names' => [
                    'index' => 'lessons',
                    'create' => 'lessons.create',
                    'store' => 'lessons.store',
                    'edit' => 'lessons.edit',
                    'update' => 'lessons.update',
                ]
            ]);

            Route::post('/categories/{id_category}/questions/type', 'QuestionsController@type');
            Route::post('/categories/{id_category}/questions/{id_question}', 'QuestionsController@check');
            Route::resource('/categories/{id_category}/questions', 'QuestionsController', [
                'names' => [
                    'show' => 'categories.show.questions.show',
                    'create' => 'categories.show.questions.create',
                    'store' => 'categories.show.questions.store',
                    'edit' => 'categories.show.questions.edit',
                    'update' => 'categories.show.questions.update',
                ]
            ]);
            Route::delete('/categories/{id_category}/questions-delete', 'QuestionsController@delete');

            Route::resource('/menus/{id_menu}/files', 'FilesController', [
                'only' => ['create', 'store', 'edit', 'update', 'destroy'],
                'names' => [
                    'create' => 'menus.files.create',
                    'store' => 'menus.files.store',
                    'edit' => 'menus.files.edit',
                    'update' => 'menus.files.update',
                    'destroy' => 'menus.files.destroy',
                ]
            ]);

            Route::get('/menus/{id_menu}/tests/{id_test}/attempts', 'TestsController@attempts')->name('menus.tests.attempts');
            Route::get('/menus/{id_menu}/tests/{id_test}/questions', 'TestsController@testQuestions')->name('menus.tests.questions');
            Route::get('/menus/{id_menu}/tests/{id_test}/questions-add', 'TestsController@categoryQuestions')->name('menus.tests.questions-add');
            Route::post('/menus/{id_menu}/tests/{id_test}/questions-add', 'TestsController@addQuestions');
            Route::get('/menus/{id_menu}/tests/{id_test}/questions/filter', 'TestsController@search')->name('menus.tests.search');
            Route::delete('/menus/{id_menu}/tests/{id_test}/questions', 'TestsController@deleteQuestions');
            Route::resource('/menus/{id_menu}/tests', 'TestsController', [
                'only' => ['create', 'store', 'edit', 'update', 'destroy'],
                'names' => [
                    'create' => 'menus.tests.create',
                    'store' => 'menus.tests.store',
                    'edit' => 'menus.tests.edit',
                    'update' => 'menus.tests.update',
                    'destroy' => 'menus.tests.destroy',
                ]
            ]);


            Route::get('/menus/{id_menu}/contents/{id_content}/visible-off', 'ContentsController@visibleOff');
            Route::get('/menus/{id_menu}/contents/{id_content}/visible-on', 'ContentsController@visibleOn');
            Route::resource('/menus/{id_menu}/contents', 'ContentsController', [
                'names' => [
                    'edit' => 'menus.contents.edit',
                ]
            ]);
        });

        Route::post('/menus/update-position', 'MenusController@updatePosition');
        Route::get('/users/turn-edit', 'UsersController@turnEdit');

        Route::post('/classification/update-credit', 'ClassificationController@updateCredit');
        Route::post('/classification/update-exam', 'ClassificationController@updateExam');

        Route::post('/contents/update-position', 'ContentsController@updatePosition');

        Route::post('/attempts/update-point', 'AttemptsController@updatePoint');

        Route::post('/questions/update-position', 'QuestionsController@updatePosition');
        Route::post('/questions/update-point', 'QuestionsController@updatePoint');
    });

    Route::group([
        'namespace' => 'Student',
        'as' => 'student.'
    ], function () {
        Route::get('/subjects', 'SubjectsController@index')->name('subjects.index');
        Route::get('/subjects/{id_subject}/enroll', 'SubjectsController@enroll');
        Route::get('/subjects/{id_subject}/unroll', 'SubjectsController@unroll');
        Route::get('/subjects/filter', 'SubjectsController@filter')->name('subjects.filter');

        Route::resource('/exam-dates', 'ExamDatesController', ['names' => [
            'index' => 'exam-dates',
        ]]);
        Route::get('/exam-dates/{examDates_id}/enroll', 'ExamDatesController@enroll');
        Route::get('/exam-dates/{examDates_id}/unroll', 'ExamDatesController@unroll');

        Route::resource('/classification', 'ClassificationController', ['names' => [
            'index' => 'classification',
        ]]);

        Route::resource('/lessons', 'LessonsController', ['names' => [
            'index' => 'lessons',
        ]]);
        Route::post('/lessons/pre-registration', 'LessonsController@preregistration');
        Route::post('/lessons/pre-unregistration', 'LessonsController@preunregistration');
        Route::post('/lessons/registration', 'LessonsController@registration');

        Route::resource('/years/{year}/schedules', 'SchedulesController', [
            'only' => ['index'],
            'names' => [
                'index' => 'years.schedules'
            ]
        ]);
        Route::resource('/years', 'YearsController', [
            'only' => ['index'],
            'names' => [
                'index' => 'years'
            ]
        ]);

        Route::resource('/subjects/{id_subject}/menus/{id_menu}/tests', 'TestsController', [
            'only' => ['show'],
            'names' => [
                'show' => 'subjects.menus.tests.show'
            ]
        ]);
        Route::get('/subjects/{id_subject}/menus/{id_menu}/tests/{id_test}/enroll', 'TestsController@enroll');
        Route::post('/subjects/{id_subject}/menus/{id_menu}/tests/{id_test}', 'TestsController@check');
        Route::post('/subjects/{id_subject}/menus/{id_menu}/tests/{id_test}/enroll', 'TestsController@verify');

        Route::get('/notifications/delete', 'NotificationsController@destroy')->name('notifications.destroy');

        Route::get('/users/subjects', 'UsersController@subjects');
        Route::get('/users/profile', 'UsersController@profile');
        Route::get('/users/password/edit', 'UsersController@passwordEdit')->name('password.edit');
        Route::put('/users/password/update', 'UsersController@passwordUpdate')->name('password.update');
        Route::get('/users/profile/filter', 'UsersController@filter')->name('profile.filter');

        Route::get('/subjects/{id}', 'SubjectsController@show')->name('subjects');
        Route::get('/subjects/{id}/sylabus', 'SubjectsController@sylabus')->name('subjects.sylabus');
        Route::get('/subjects/{id}/contacts', 'SubjectsController@contacts')->name('subjects.contacts');

        Route::get('/subjects/{id_subject}/menus/{id}', 'MenusController@show')->name('subjects.menus');

        Route::resource('/subjects/{id_subject}/menus/{id_menu}/files', 'FilesController', ['only' => ['show']]);

        Route::resource('/subjects/{id_subject}/menus/{id_menu}/tests/{id_test}/attempts', 'AttemptsController', [
                'only' => ['show', 'destroy'],

            ]);
    });
});

Route::get('/', [PagesController::class, 'index'])->name('index');

Auth::routes(['register' => false]);

